## Analysis of changes in canopy cover, as measured with a sphereical densiometer ##

library(lsmeans)
library(lmerTest)
library(lme4)
library(plyr)
library(psych)
library(multcomp)

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")
  
densio<-read.table("Canopy Cover_Densiometer.csv",sep=',',header=T)

attach(densio)

describeBy(Densio15, group = NULL)
  describeBy(Densio15, group = Site)
  describeBy(Densio15, group = Treatment)
describeBy(Densio16, group = Treatment) 
describeBy(Densio17, group = Treatment) 

describeBy(Densio16-Densio15, group = Treatment) 
describeBy(Densio17-Densio15, group = Treatment) 

contrast.matrix1<- rbind("Ref vs. 0"          =c(1,   0,   0,   0,   0),
                        "Ref vs. Cut-"        =c(0,   1,   0,   0,   0),
                        "Ref vs. Fecon+"      =c(0,   0,   0,   0,   1),
                        "Cut vs. Fecon"       =c(0,-0.5,-0.5, 0.5, 0.5),
                        "Unmulched vs Mulched"=c(0,-0.5, 0.5,-0.5, 0.5),
                        "Cut- vs Fecon+"      =c(0,  -1,   0,   0,   1))


lm.canopy15<-lmer(Densio15~Treatment+(1|Site))
  plot(lm.canopy15)
  hist(residuals(lm.canopy15))
    
  anova(lm.canopy15)
  
lm.canopy1516<-lmer(Densio16-Densio15~Treatment+(1|Site))
  plot(lm.canopy1516)
  hist(residuals(lm.canopy1516))
  
  anova(lm.canopy1516)  
  summary(glht(lm.canopy1516, contrast.matrix1))
  
lm.canopy16<-lmer(Densio16~Treatment+(1|Site))
  plot(lm.canopy16)
  hist(residuals(lm.canopy16))
  
  anova(lm.canopy16)

lm.canopy1517<-lmer(Densio17-Densio15~Treatment+(1|Site))
  plot(lm.canopy1517)
  hist(residuals(lm.canopy1517))
  
  anova(lm.canopy1517)   
  summary(glht(lm.canopy1517, contrast.matrix1))
  
lm.canopy17<-lmer(Densio17~Treatment+(1|Site))
  plot(lm.canopy17)
  hist(residuals(lm.canopy17))
  
  anova(lm.canopy17)
  

ave15<-aggregate(Densio15~Removal,FUN=mean)
ave16<-aggregate(Densio16~Removal, FUN=mean)[,2]
densio.h<-cbind(ave15,ave16)
dht<-apply(densio.h[,2:3], 1, as.numeric)
colnames(dht)=c("Ref", "Cut Stump","Fecon")
rownames(dht)=c("2015","2016")

se15<-aggregate(Densio15~Removal,FUN=sd)[,2]/sqrt(32)
se16<-aggregate(Densio16~Removal,FUN=sd)[,2]/sqrt(32)
densio.se<-cbind(se15,se16)



densio.allyears<-c(Densio15, Densio16, Densio17)
  year<-c(rep(0,96),rep(1,96), rep(2,96))

densio.long<-cbind.data.frame(rep(densio[,1:6],3),year,densio.allyears)
detach(densio)


contrast.matrix<- rbind("Year:Ref vs. 0"=c(0,1,0,0,0,0,0,0,0,0),
                         "Year:Ref vs. Year:Cut-"=c(0, 0, 0, 0, 0, 0, 1, 0, 0, 0),
                         "Year:Ref vs. Year:Fecon+"=c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1),
                         "Year:Cut vs Year:Fecon" = c(0, 0, 0, 0, 0, 0, -0.5, -0.5, 0.5, 0.5),
                         "Year:Unmulched vs Year:Mulched" = c(0, 0, 0, 0, 0, 0, -0.5, 0.5, -0.5, 0.5),
                         "Year:Cut- vs Year:Fecon+" = c(0, 0, 0, 0, 0, 0, -1, 0, 0, 1))



attach(densio.long)
lmm.dens.rep<-lmer(densio.allyears~year*Treatment+(year|Site:Plot)+(1|Site))  
  plot(lmm.dens.rep)
  hist(residuals(lmm.dens.rep))
    anova(lmm.dens.rep)
    summary(lmm.dens.rep)
    summary(glht(lmm.dens.rep, contrast.matrix))
    
    
detach(densio.long)
