## Analysis of mulching head treatment depth effects on honeysuckle resprouting ##
## Experiment was done with a separate set of mulching head treatment sites than 
## experiment examining other vegetation responses 

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")

library(rms)
library(lme4)
library(lmerTest)
library(lsmeans)
library(multcomp)
library(psych)
library(piecewiseSEM)

fecon.resprouts<-read.table("Fecon Resprouts.csv",sep=',',header=T)
    
fecon.resprouts$Fecon.Intensity<-fecon.resprouts$Treatment.Depth*-1  #so that positive numbers = below soil surface, and negative numbers = above soil surface 
                                                     #(i.e. larger number = more intense)
fecon.resprouts$Resprout.density<-fecon.resprouts$Resprout.count*40 #multiply per plot values to attain density per 100m^2


fecon.resprouts$total.shrub.volume<-(((4/3)*pi*(fecon.resprouts$Height.ave/2)*
    (fecon.resprouts$Length.ave/2)*(fecon.resprouts$Width.ave/2))*fecon.resprouts$Resprout.density)

fecon.resprouts$single.shrub.volume<-((4/3)*pi*(fecon.resprouts$Height.ave/2)*
    (fecon.resprouts$Length.ave/2)*(fecon.resprouts$Width.ave/2))

attach(fecon.resprouts)

plot(Fecon.Intensity, Resprout.density)
  plot(Fecon.Intensity, log(Resprout.density+1))
plot(Fecon.Intensity, single.shrub.volume)
  plot(Fecon.Intensity, log(single.shrub.volume+1))
plot(Fecon.Intensity, total.shrub.volume)
  plot(Fecon.Intensity, log(total.shrub.volume+1))
  
lmm.density<-lmer(Resprout.density~Fecon.Intensity+(1|Site))
  plot(lmm.density)
  lmm.density.log<-lmer(log(Resprout.density+1)~Fecon.Intensity+(1|Site))
    plot(lmm.density.log)
    hist(residuals(lmm.density.log), breaks=6)
    
    summary(lmm.density.log) #significant negative effect of Fecon intensity on resprout count
    rsquared(lmm.density.log) #marginal r2 (variance explained by fixed effects alone) = 0.0696
                                    #conditional r2 (var explained by fixed and random effects) = 0.8304
    
    
lmm.volume<-lmer(single.shrub.volume~Fecon.Intensity+(1|Site))
  plot(lmm.volume)
    
    lmm.volume.log<-lmer(log(single.shrub.volume+1)~Fecon.Intensity+(1|Site))
      plot(lmm.volume.log)
        hist(residuals(lmm.volume.log), breaks=6)
        
        summary(lmm.volume.log) #significant negative effect of Fecon intensity on average volume of resprouting stumps
        rsquared(lmm.volume.log) #marginal r2 = 0.1121; conditional r2 = 0.6774
        
lmm.TotVol<-lmer(total.shrub.volume~Fecon.Intensity+(1|Site), data=fecon.resprouts)
  plot(lmm.TotVol)
 
  lmm.TotVol.log<-lmer(log10(total.shrub.volume+1)~Fecon.Intensity+(1|Site), data=fecon.resprouts)
    plot(lmm.TotVol.log)
      hist(residuals(lmm.TotVol.log), breaks=6)

      lm.TotVol.log<-lm(log10(total.shrub.volume+1)~Fecon.Intensity, data=fecon.resprouts)
        summary(lm.TotVol.log)
      
      
      summary(lmm.TotVol.log) #significant negative effect of Fecon intensity on total volume of resprouting stumps
      rsquared(lmm.TotVol.log)
    
    par(mar=c(5,5,4,1)+0.1)
  
    plot(log(total.shrub.volume+1)~Fecon.Intensity, xlab="", ylab="",
         pch=as.numeric(Site)+16,cex = 1.5,col=colors()[282],xlim=c(-2.2,1.5), ylim=c(13.8,17.5),axes=F)
        abline(15.2453,-0.6185, lwd=2)
        axis(side=1, at=c(-2.2,seq(-2,1.5,by=0.5)), labels = c("",seq(-2,1.5,by=0.5)), cex.axis=1.3)
        axis(side=2, at=c(13.8,seq(14,17,by=1),17.5),labels=c("",seq(14,17,by=1),""),las=1, cex.axis=1.3)
        mtext(side=1,"Treatment Depth (cm)",cex=1.3,line=3)
        mtext(side =2,expression("log (Shrub Volume) (cm  "^3*" 100 m "^-2*")"), cex=1.3,line =3)
        text(x=1,y=17.3,expression("Marginal R"^2*"= 0.331"), cex=1.3)
        
#### Plotting Confidence Interval Around Regression Line ####
    library(ggplot2)
    
    #Template Code (Kyle Rose)
    #pubTheme.notitle <-theme(plot.title=element_text(size=18, face="bold"),
    #                          axis.ticks=element_line(colour="black"),
    #                          axis.title.y=element_text(size=12),
    #                          axis.title.x=element_blank(),
    #                          axis.text=element_text(size=9, colour="black"),
    #                          legend.text=element_text(size=12),
    #                          legend.title=element_text(size=14),
    #                          panel.background=element_blank(),
    #                          panel.grid=element_blank(),
    #                          panel.border=element_rect(colour="black", fill=NA),
    #                          legend.key=element_blank())
    
    #RH.CANOPY.FERT1 <- ggplot(DHHL, aes(CO, RHG1))
    #RH1 <- RH.CANOPY.FERT1 + 
    #  #geom_point(aes(color=FERT), size=3)+
    #  geom_smooth(aes(lty=FERT), colour="black", fill="black", size=1, method="lm")+
    #  ylim(0,600)+
    #  xlab("\n Canopy Openness")+
    #  scale_x_continuous(breaks = c(0.3,0.4,0.5,0.6,0.7,0.8))+
    #  ylab("RHG (%) \n")+
    #  #labs(title = "Relative Height Growth (%) after 1 year")+
    #  pubTheme+
    #  labs(lty="Fertilizer", shape="Fertilizer")+
    #  scale_linetype_discrete(breaks=c("0", "1", "2"), labels=c("0 g", "40 g", "80 g"))
    
    
    #My modifications
    pubTheme.Fecon <-theme(plot.title=element_text(size=18, face="bold"),
                           plot.margin=margin(1,2,5,15,"pt"),
                             axis.ticks=element_line(colour="black"),
                             axis.title.y=element_text(size=14, margin=margin(r=20)),
                             axis.title.x=element_text(size=14, margin=margin(t=20)),
                             axis.text=element_text(size=14, colour="black"),
                             legend.text=element_text(size=12, colour="black"),
                             legend.title=element_text(size=14, colour="black"),
                             panel.background=element_blank(),
                             panel.grid=element_blank(),
                             panel.border=element_rect(colour="black", fill=NA),
                             legend.key=element_blank(),
                             legend.position = c(0.85,0.85),
                             legend.box.background = element_blank())

  SiteLabel<-c(rep("LF-A",8),rep("LF-B",8),rep("PWA-A",8))

 tiff("Fig. 2_Mulching Head Treatment Depth.tiff", compression = "lzw", height= 4.5, width = 6.5, units = "in", res=400, pointsize = 11) 
    tot_vol.int <- ggplot(fecon.resprouts, aes(fecon.resprouts$Fecon.Intensity, log10(fecon.resprouts$total.shrub.volume+1)))
    FcInt1 <- tot_vol.int + 
      geom_point(aes(shape=SiteLabel,colour=SiteLabel), size=3)+
      geom_smooth(colour="black", fill="royalblue3", size=1, method="lm", formula = y~x)+
      xlab("Mulching Head Intensity (cm below soil surface)")+
      ylab(expression("log"[10]*" Shrub Volume (cm"^3*" / 100 m"^2*")"))+
      scale_x_continuous(breaks = c(-2.0, -1.5,-1,-0.5,0,0.5,1,1.5))+
      #annotate("text",label=bquote("Marginal R"^2*" = 0.331"), x=1,y=7)+
      pubTheme.Fecon + 
      scale_color_manual(values = c("#108CA0", "#DA8904","#040404")) +
      labs(shape='Site',colour="Site")
    
    print(FcInt1)
    dev.off()
    
