### Analysis of floristic quality ###

library(lme4)
library(lmerTest)
library(lsmeans)
library(multcomp)
library(psych)

#########################
### Floristic Quality ###
#########################

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")

comm.all<-read.table("Veg Community Cover Values.csv", header=T, sep=',')
  nrow(comm.all)
  ncol(comm.all)
  head(comm.all)

#Reorder factors for appropriate reference levels  
comm.all$Mulch<-factor(comm.all$Mulch, levels(comm.all$Mulch)[c(2,1,3)])
  levels(comm.all$Mulch) #ref should be first
comm.all$Treatment<-factor(comm.all$Treatment, levels(comm.all$Treatment)[c(5,1,2,3,4)])
  levels(comm.all$Treatment) #ref should be first
comm.all$Removal<-factor(comm.all$Removal, levels(comm.all$Removal)[c(3,1,2)])
  levels(comm.all$Removal) #ref should be first

#Subset by study year
comm.15<-subset(comm.all, comm.all$Year=="2015")
  nrow(comm.15)
comm.16<-subset(comm.all, comm.all$Year=="2016")
  nrow(comm.16)
comm.17<-subset(comm.all, comm.all$Year=="2017")
  nrow(comm.17)  

#define some species groups 
  graminoids<-c("Grass.h","Carex.h")  
  unk.seed<-c("UnkWoody30.s","UnkWoody42.s","UnkWoody45.s")
  unk.herb<-c("Cirsiumsp3.h","Polemoniaceae.h","Unk1.2017.h","Unk2017.h",
              "Unk3.2017.h","Unk11.2017.h","Unk6.2017.h","Unk8.2017.h",
              "UnkAster10.h","UnkAster4.h","UnkAster6.h","UnkAster8.h",
              "UnkAster9.h","UnkOppo1.h","UnkOppo2.h","UnkPolemoniaceae.h",
              "UnkRosette1.h","UnkRosette2.h")
  
#make same adjustments to community matrix (described in text)
  comm.fqi.procA<-comm.all[,-which(names(comm.all) %in% graminoids)] #drop graminoids from calculation
    head(comm.fqi.procA)
  comm.fqi.procB<-comm.fqi.procA[,-which(names(comm.fqi.procA) %in% unk.herb),] #drop unknown herbs from calculation
    head(comm.fqi.procB)
  comm.fqi<-comm.fqi.procB[,-which(names(comm.fqi.procB) %in% unk.seed),] #drop unknown seedlings from calculation; kept Viburnum spp. b/c it's likely an ornamental/exotic
    head(comm.fqi)
  
head(comm.fqi)
  comm.fqi.15<-subset(comm.fqi, comm.fqi$Year=="2015")
    nrow(comm.fqi.15)
  comm.fqi.16<-subset(comm.fqi, comm.fqi$Year=="2016")
    nrow(comm.fqi.16)
  comm.fqi.17<-subset(comm.fqi, comm.fqi$Year=="2017")
    nrow(comm.fqi.17)  
  
    
spp.list<-read.table("Species List and Conservation Coefficients.csv", sep=',', header=T) #conservation coefficients
CC<-cbind.data.frame(spp.list$Species.Code,spp.list$Coefficient.of.Conservation)
  colnames(CC)<-c("Species", "Con.Coef")    
    
    CC.comm.procA<-CC[-which(CC$Species %in% graminoids),] #drop graminoids from calculation
    CC.comm.procB<-CC.comm.procA[-which(CC.comm.procA$Species %in% unk.herb),] #drop unknown herbs from calculation
    CC.comm<-CC.comm.procB[-which(CC.comm.procB$Species %in% unk.seed),] #drop unknown seedlings from calculation
    
#2015 
  t.comm15<-as.data.frame(t(comm.fqi.15[,7:128]))
    colnames(t.comm15)<-comm.fqi.15$Plot
  t.comm15$Species<-as.factor(rownames(t.comm15))
  
  comm.15.CC<-merge(t.comm15,CC.comm, by="Species") 
  
#2016    
  t.comm16<-as.data.frame(t(comm.fqi.16[,7:127]))
    colnames(t.comm16)<-comm.fqi.16$Plot
  t.comm16$Species<-as.factor(rownames(t.comm16))
  
  comm.16.CC<-merge(t.comm16,CC.comm, by="Species") 

#2017  
  t.comm17<-as.data.frame(t(comm.fqi.17[,7:128]))
    colnames(t.comm17)<-comm.fqi.17$Plot
  t.comm17$Species<-as.factor(rownames(t.comm17))
  
  comm.17.CC<-merge(t.comm17,CC.comm, by="Species") 
  
##########################################
### as per Rothrock and Homoya, 
# calculate FQI as CC(ave)*sqrt(spp number)

comm.15.occur<-ifelse(comm.15.CC[,2:97]>0,1,0)
specnumber.15<-colSums(comm.15.occur)
comm.15.2<-comm.15.occur*comm.15.CC$Con.Coef
CC.sum.15<-colSums(comm.15.2)
CC.ave.15<-CC.sum.15/specnumber.15

comm.16.occur<-ifelse(comm.16.CC[,2:97]>0,1,0)
specnumber.16<-colSums(comm.16.occur)
comm.16.2<-comm.16.occur*comm.16.CC$Con.Coef
CC.sum.16<-colSums(comm.16.2)
CC.ave.16<-CC.sum.16/specnumber.16

comm.17.occur<-ifelse(comm.17.CC[,2:97]>0,1,0)
specnumber.17<-colSums(comm.17.occur)
comm.17.2<-comm.17.occur*comm.17.CC$Con.Coef
CC.sum.17<-colSums(comm.17.2)
CC.ave.17<-CC.sum.17/specnumber.17

describeBy(CC.ave.15, comm.15$Treatment)
describeBy(CC.ave.16, comm.16$Treatment)
describeBy(CC.ave.17, comm.17$Treatment)

FQI2.15<-CC.ave.15*sqrt(specnumber.15)
FQI2.16<-CC.ave.16*sqrt(specnumber.16)
FQI2.17<-CC.ave.17*sqrt(specnumber.17)

FQI2.matrix<-cbind.data.frame(comm.all[,1:6],c(FQI2.15,FQI2.16,FQI2.17))
  colnames(FQI2.matrix)[7]<-"FQI2"
  FQI2.matrix$Year.rel<- FQI2.matrix$Year - 2015
  is.nan.data.frame <- function(x)
    do.call(cbind, lapply(x, is.nan))
  
  FQI2.matrix[is.nan(FQI2.matrix)] <- 0
attach(FQI2.matrix)

lm.FQI2<-lmer(FQI2~Treatment*Year.rel+(Year.rel|Site:Plot)+(1|Site))
  plot(lm.FQI2)
  hist(residuals(lm.FQI2))
  anova(lm.FQI2)
  
  contrast.matrix <- rbind("Year:Ref vs. 0" = c(0, 1, 0, 0, 0, 0, 0, 0, 0, 0),
                           "Year:Ref vs. Year:Cut-" =  c(0, 0, 0, 0, 0, 0, 1, 0, 0, 0),
                           "Year:Ref vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1),
                           "Year:Unmulched vs Year:Mulched"=c(0,0,0,0,0,0,-0.5,0.5,-0.5,0.5),
                           "Year:Cut vs Year:Fecon"=c(0,0,0,0,0,0,-0.5,-0.5,0.5,0.5),
                           "Year:Cut- vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, -1, 0, 0, 1))
  
  summary(glht(lm.FQI2, contrast.matrix))
  
  describeBy(FQI2.15,FQI2.matrix$Treatment[1:96])
  describeBy(FQI2.16,FQI2.matrix$Treatment[1:96])
  describeBy(FQI2.17,FQI2.matrix$Treatment[1:96])
  
  rem.ind<-rep(c(rep("Trt",16),rep("Ref",8)),4)
  
  describeBy(FQI2.15, rem.ind)
  describeBy(FQI2.16, rem.ind)
  describeBy(FQI2.17, rem.ind)
  
detach(FQI2.matrix)

CAve.matrix<-cbind.data.frame(comm.all[,1:6],c(CC.ave.15,CC.ave.16,CC.ave.17))
  colnames(CAve.matrix)[7]<-"CAve"
  CAve.matrix$Year.rel<- CAve.matrix$Year - 2015
is.nan.data.frame <- function(x)
  do.call(cbind, lapply(x, is.nan))

CAve.matrix[is.nan(CAve.matrix)] <- 0
  

#linegraphs
  CAve.means<-data.frame(matrix(vector(), 5, 3,
                                dimnames=list(c(), c("2015", "2016", "2017"))),
                         stringsAsFactors=F)
  rownames(CAve.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
  CAve.means[,1]<-c(describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Ref`[,"mean"],
                    describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Cut-`[,"mean"],
                    describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Cut+`[,"mean"],
                    describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Fecon-`[,"mean"],
                    describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Fecon+`[,"mean"])
  CAve.means[,2]<-c(describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Ref`[,"mean"],
                    describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Cut-`[,"mean"],
                    describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Cut+`[,"mean"],
                    describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Fecon-`[,"mean"],
                    describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Fecon+`[,"mean"])
  CAve.means[,3]<-c(describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Ref`[,"mean"],
                    describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Cut-`[,"mean"],
                    describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Cut+`[,"mean"],
                    describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Fecon-`[,"mean"],
                    describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Fecon+`[,"mean"])
  
  CAve.15.rf<-CAve.means[1,1]
  CAve.15.cn<-CAve.means[2,1]
  CAve.15.cw<-CAve.means[3,1]
  CAve.15.fn<-CAve.means[4,1]
  CAve.15.fw<-CAve.means[5,1]
  CAve.16.rf<-CAve.means[1,2]
  CAve.16.cn<-CAve.means[2,2]
  CAve.16.cw<-CAve.means[3,2]
  CAve.16.fn<-CAve.means[4,2]
  CAve.16.fw<-CAve.means[5,2]
  CAve.17.rf<-CAve.means[1,3]
  CAve.17.cn<-CAve.means[2,3]
  CAve.17.cw<-CAve.means[3,3]
  CAve.17.fn<-CAve.means[4,3]
  CAve.17.fw<-CAve.means[5,3]
  
  
  CAve.se <- data.frame(matrix(vector(), 5, 3,
                               dimnames=list(c(), c("2015", "2016", "2017"))),
                        stringsAsFactors=F)
  rownames(CAve.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
  CAve.se[,1]<-c(describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Ref`[,"se"],
                 describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Cut-`[,"se"],
                 describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Cut+`[,"se"],
                 describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Fecon-`[,"se"],
                 describeBy(CC.ave.15,group=CAve.matrix$Treatment[1:96])$`Fecon+`[,"se"])
  CAve.se[,2]<-c(describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Ref`[,"se"],
                 describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Cut-`[,"se"],
                 describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Cut+`[,"se"],
                 describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Fecon-`[,"se"],
                 describeBy(CC.ave.16,group=CAve.matrix$Treatment[1:96])$`Fecon+`[,"se"])
  CAve.se[,3]<-c(describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Ref`[,"se"],
                 describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Cut-`[,"se"],
                 describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Cut+`[,"se"],
                 describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Fecon-`[,"se"],
                 describeBy(CC.ave.17,group=CAve.matrix$Treatment[1:96])$`Fecon+`[,"se"])
  
  CAve_se.15.rf<-CAve.se[1,1]
  CAve_se.15.cn<-CAve.se[2,1]
  CAve_se.15.cw<-CAve.se[3,1]
  CAve_se.15.fn<-CAve.se[4,1]
  CAve_se.15.fw<-CAve.se[5,1]
  CAve_se.16.rf<-CAve.se[1,2]
  CAve_se.16.cn<-CAve.se[2,2]
  CAve_se.16.cw<-CAve.se[3,2]
  CAve_se.16.fn<-CAve.se[4,2]
  CAve_se.16.fw<-CAve.se[5,2]
  CAve_se.17.rf<-CAve.se[1,3]
  CAve_se.17.cn<-CAve.se[2,3]
  CAve_se.17.cw<-CAve.se[3,3]
  CAve_se.17.fn<-CAve.se[4,3]
  CAve_se.17.fw<-CAve.se[5,3]
  
  
  
  
  
  FQI2.means <- data.frame(matrix(vector(), 5, 3,
                                 dimnames=list(c(), c("2015", "2016", "2017"))),
                          stringsAsFactors=F)
  rownames(FQI2.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
  FQI2.means[,1]<-c(describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Ref`[,"mean"],
                   describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Cut-`[,"mean"],
                   describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Cut+`[,"mean"],
                   describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Fecon-`[,"mean"],
                   describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Fecon+`[,"mean"])
  FQI2.means[,2]<-c(describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Ref`[,"mean"],
                   describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Cut-`[,"mean"],
                   describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Cut+`[,"mean"],
                   describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Fecon-`[,"mean"],
                   describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Fecon+`[,"mean"])
  FQI2.means[,3]<-c(describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Ref`[,"mean"],
                   describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Cut-`[,"mean"],
                   describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Cut+`[,"mean"],
                   describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Fecon-`[,"mean"],
                   describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Fecon+`[,"mean"])
  
  
  # Error Bar Function
  plotsegraph <- function(loc, value, sterr, wiskwidth, color = "grey", linewidth = 1) {
    
    w <- wiskwidth/2
    segments(x0 = loc, x1 = loc, y0 = value - sterr, y1 = value + sterr, col = color, 
             lwd = linewidth)
    segments(x0 = loc - w, x1 = loc + w, y0 = value + sterr, y1 = value + sterr, 
             col = color, lwd = linewidth)  # upper whiskers
    segments(x0 = loc - w, x1 = loc + w, y0 = value - sterr, y1 = value - sterr, 
             col = color, lwd = linewidth)  # lower whiskers
  }
  
#Create objects for individual means  
  FQI2.15.rf<-FQI2.means[1,1]
  FQI2.15.cn<-FQI2.means[2,1]
  FQI2.15.cw<-FQI2.means[3,1]
  FQI2.15.fn<-FQI2.means[4,1]
  FQI2.15.fw<-FQI2.means[5,1]
  FQI2.16.rf<-FQI2.means[1,2]
  FQI2.16.cn<-FQI2.means[2,2]
  FQI2.16.cw<-FQI2.means[3,2]
  FQI2.16.fn<-FQI2.means[4,2]
  FQI2.16.fw<-FQI2.means[5,2]
  FQI2.17.rf<-FQI2.means[1,3]
  FQI2.17.cn<-FQI2.means[2,3]
  FQI2.17.cw<-FQI2.means[3,3]
  FQI2.17.fn<-FQI2.means[4,3]
  FQI2.17.fw<-FQI2.means[5,3]
  
  
FQI2.se <- data.frame(matrix(vector(), 5, 3,
                                  dimnames=list(c(), c("2015", "2016", "2017"))),
                           stringsAsFactors=F)
  rownames(FQI2.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
  FQI2.se[,1]<-c(describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Ref`[,"se"],
                    describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Cut-`[,"se"],
                    describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Cut+`[,"se"],
                    describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Fecon-`[,"se"],
                    describeBy(FQI2.15,group=FQI2.matrix$Treatment[1:96])$`Fecon+`[,"se"])
  FQI2.se[,2]<-c(describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Ref`[,"se"],
                    describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Cut-`[,"se"],
                    describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Cut+`[,"se"],
                    describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Fecon-`[,"se"],
                    describeBy(FQI2.16,group=FQI2.matrix$Treatment[1:96])$`Fecon+`[,"se"])
  FQI2.se[,3]<-c(describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Ref`[,"se"],
                    describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Cut-`[,"se"],
                    describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Cut+`[,"se"],
                    describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Fecon-`[,"se"],
                    describeBy(FQI2.17,group=FQI2.matrix$Treatment[1:96])$`Fecon+`[,"se"])
  
  FQI2_se.15.rf<-FQI2.se[1,1]
  FQI2_se.15.cn<-FQI2.se[2,1]
  FQI2_se.15.cw<-FQI2.se[3,1]
  FQI2_se.15.fn<-FQI2.se[4,1]
  FQI2_se.15.fw<-FQI2.se[5,1]
  FQI2_se.16.rf<-FQI2.se[1,2]
  FQI2_se.16.cn<-FQI2.se[2,2]
  FQI2_se.16.cw<-FQI2.se[3,2]
  FQI2_se.16.fn<-FQI2.se[4,2]
  FQI2_se.16.fw<-FQI2.se[5,2]
  FQI2_se.17.rf<-FQI2.se[1,3]
  FQI2_se.17.cn<-FQI2.se[2,3]
  FQI2_se.17.cw<-FQI2.se[3,3]
  FQI2_se.17.fn<-FQI2.se[4,3]
  FQI2_se.17.fw<-FQI2.se[5,3]
  
  
## Legend Function Modification
  
  LEGEND <- function (x, y = NULL, legend, fill = NULL, 
                      col = par("col"), pt.col=col, line.col=col,
                      border = "black", lty, lwd, pch, angle = 45, density = NULL,
                      bty = "o", bg = par("bg"), box.lwd = par("lwd"), box.lty = par("lty"),
                      box.col = par("fg"), pt.bg = NA, cex = 1, pt.cex = cex, pt.lwd = lwd,
                      xjust = 0, yjust = 1, x.intersp = 1, y.intersp = 1, adj = c(0,
                                                                                  0.5), text.width = NULL, text.col = par("col"), text.font = NULL,
                      merge = do.lines && has.pch, trace = FALSE, plot = TRUE,
                      ncol = 1, horiz = FALSE, title = NULL, inset = 0, xpd, title.col = text.col,
                      title.adj = 0.5, seg.len = 2)
  {
    if (missing(legend) && !missing(y) && (is.character(y) ||
                                           is.expression(y))) {
      legend <- y
      y <- NULL
    }
    mfill <- !missing(fill) || !missing(density)
    if (!missing(xpd)) {
      op <- par("xpd")
      on.exit(par(xpd = op))
      par(xpd = xpd)
    }
    title <- as.graphicsAnnot(title)
    if (length(title) > 1)
      stop("invalid 'title'")
    legend <- as.graphicsAnnot(legend)
    n.leg <- if (is.call(legend))
      1
    else length(legend)
    if (n.leg == 0)
      stop("'legend' is of length 0")
    auto <- if (is.character(x))
      match.arg(x, c("bottomright", "bottom", "bottomleft",
                     "left", "topleft", "top", "topright", "right", "center"))
    else NA
    if (is.na(auto)) {
      xy <- xy.coords(x, y)
      x <- xy$x
      y <- xy$y
      nx <- length(x)
      if (nx < 1 || nx > 2)
        stop("invalid coordinate lengths")
    }
    else nx <- 0
    xlog <- par("xlog")
    ylog <- par("ylog")
    rect2 <- function(left, top, dx, dy, density = NULL, angle,
                      ...) {
      r <- left + dx
      if (xlog) {
        left <- 10^left
        r <- 10^r
      }
      b <- top - dy
      if (ylog) {
        top <- 10^top
        b <- 10^b
      }
      rect(left, top, r, b, angle = angle, density = density,
           ...)
    }
    segments2 <- function(x1, y1, dx, dy, ...) {
      x2 <- x1 + dx
      if (xlog) {
        x1 <- 10^x1
        x2 <- 10^x2
      }
      y2 <- y1 + dy
      if (ylog) {
        y1 <- 10^y1
        y2 <- 10^y2
      }
      segments(x1, y1, x2, y2, ...)
    }
    points2 <- function(x, y, ...) {
      if (xlog)
        x <- 10^x
      if (ylog)
        y <- 10^y
      points(x, y, ...)
    }
    text2 <- function(x, y, ...) {
      if (xlog)
        x <- 10^x
      if (ylog)
        y <- 10^y
      text(x, y, ...)
    }
    if (trace)
      catn <- function(...) do.call("cat", c(lapply(list(...),
                                                    formatC), list("\n")))
    cin <- par("cin")
    Cex <- cex * par("cex")
    if (is.null(text.width))
      text.width <- max(abs(strwidth(legend, units = "user",
                                     cex = cex, font = text.font)))
    else if (!is.numeric(text.width) || text.width < 0)
      stop("'text.width' must be numeric, >= 0")
    xc <- Cex * xinch(cin[1L], warn.log = FALSE)
    yc <- Cex * yinch(cin[2L], warn.log = FALSE)
    if (xc < 0)
      text.width <- -text.width
    xchar <- xc
    xextra <- 0
    yextra <- yc * (y.intersp - 1)
    ymax <- yc * max(1, strheight(legend, units = "user", cex = cex)/yc)
    ychar <- yextra + ymax
    if (trace)
      catn("  xchar=", xchar, "; (yextra,ychar)=", c(yextra,
                                                     ychar))
    if (mfill) {
      xbox <- xc * 0.8
      ybox <- yc * 0.5
      dx.fill <- xbox
    }
    do.lines <- (!missing(lty) && (is.character(lty) || any(lty >
                                                              0))) || !missing(lwd)
    n.legpercol <- if (horiz) {
      if (ncol != 1)
        warning(gettextf("horizontal specification overrides: Number of columns := %d",
                         n.leg), domain = NA)
      ncol <- n.leg
      1
    }
    else ceiling(n.leg/ncol)
    has.pch <- !missing(pch) && length(pch) > 0
    if (do.lines) {
      x.off <- if (merge)
        -0.7
      else 0
    }
    else if (merge)
      warning("'merge = TRUE' has no effect when no line segments are drawn")
    if (has.pch) {
      if (is.character(pch) && !is.na(pch[1L]) && nchar(pch[1L],
                                                        type = "c") > 1) {
        if (length(pch) > 1)
          warning("not using pch[2..] since pch[1L] has multiple chars")
        np <- nchar(pch[1L], type = "c")
        pch <- substr(rep.int(pch[1L], np), 1L:np, 1L:np)
      }
      if (!is.character(pch))
        pch <- as.integer(pch)
    }
    if (is.na(auto)) {
      if (xlog)
        x <- log10(x)
      if (ylog)
        y <- log10(y)
    }
    if (nx == 2) {
      x <- sort(x)
      y <- sort(y)
      left <- x[1L]
      top <- y[2L]
      w <- diff(x)
      h <- diff(y)
      w0 <- w/ncol
      x <- mean(x)
      y <- mean(y)
      if (missing(xjust))
        xjust <- 0.5
      if (missing(yjust))
        yjust <- 0.5
    }
    else {
      h <- (n.legpercol + (!is.null(title))) * ychar + yc
      w0 <- text.width + (x.intersp + 1) * xchar
      if (mfill)
        w0 <- w0 + dx.fill
      if (do.lines)
        w0 <- w0 + (seg.len + x.off) * xchar
      w <- ncol * w0 + 0.5 * xchar
      if (!is.null(title) && (abs(tw <- strwidth(title, units = "user",
                                                 cex = cex) + 0.5 * xchar)) > abs(w)) {
        xextra <- (tw - w)/2
        w <- tw
      }
      if (is.na(auto)) {
        left <- x - xjust * w
        top <- y + (1 - yjust) * h
      }
      else {
        usr <- par("usr")
        inset <- rep_len(inset, 2)
        insetx <- inset[1L] * (usr[2L] - usr[1L])
        left <- switch(auto, bottomright = , topright = ,
                       right = usr[2L] - w - insetx, bottomleft = ,
                       left = , topleft = usr[1L] + insetx, bottom = ,
                       top = , center = (usr[1L] + usr[2L] - w)/2)
        insety <- inset[2L] * (usr[4L] - usr[3L])
        top <- switch(auto, bottomright = , bottom = , bottomleft = usr[3L] +
                        h + insety, topleft = , top = , topright = usr[4L] -
                        insety, left = , right = , center = (usr[3L] +
                                                               usr[4L] + h)/2)
      }
    }
    if (plot && bty != "n") {
      if (trace)
        catn("  rect2(", left, ",", top, ", w=", w, ", h=",
             h, ", ...)", sep = "")
      rect2(left, top, dx = w, dy = h, col = bg, density = NULL,
            lwd = box.lwd, lty = box.lty, border = box.col)
    }
    xt <- left + xchar + xextra + (w0 * rep.int(0:(ncol - 1),
                                                rep.int(n.legpercol, ncol)))[1L:n.leg]
    yt <- top - 0.5 * yextra - ymax - (rep.int(1L:n.legpercol,
                                               ncol)[1L:n.leg] - 1 + (!is.null(title))) * ychar
    if (mfill) {
      if (plot) {
        if (!is.null(fill))
          fill <- rep_len(fill, n.leg)
        rect2(left = xt, top = yt + ybox/2, dx = xbox, dy = ybox,
              col = fill, density = density, angle = angle,
              border = border)
      }
      xt <- xt + dx.fill
    }
    if (plot && (has.pch || do.lines)) {
      pt.COL <- rep_len(pt.col, n.leg)
      line.COL <- rep_len(line.col, n.leg)
    }
    if (missing(lwd) || is.null(lwd))
      lwd <- par("lwd")
    if (do.lines) {
      if (missing(lty) || is.null(lty))
        lty <- 1
      lty <- rep_len(lty, n.leg)
      lwd <- rep_len(lwd, n.leg)
      ok.l <- !is.na(lty) & (is.character(lty) | lty > 0) &
        !is.na(lwd)
      if (trace)
        catn("  segments2(", xt[ok.l] + x.off * xchar, ",",
             yt[ok.l], ", dx=", seg.len * xchar, ", dy=0, ...)")
      if (plot)
        segments2(xt[ok.l] + x.off * xchar, yt[ok.l], dx = seg.len *
                    xchar, dy = 0, lty = lty[ok.l], lwd = lwd[ok.l],
                  col = line.COL[ok.l])
      xt <- xt + (seg.len + x.off) * xchar
    }
    if (has.pch) {
      pch <- rep_len(pch, n.leg)
      pt.bg <- rep_len(pt.bg, n.leg)
      pt.cex <- rep_len(pt.cex, n.leg)
      pt.lwd <- rep_len(pt.lwd, n.leg)
      ok <- !is.na(pch)
      if (!is.character(pch)) {
        ok <- ok & (pch >= 0 | pch <= -32)
      }
      else {
        ok <- ok & nzchar(pch)
      }
      x1 <- (if (merge && do.lines)
        xt - (seg.len/2) * xchar
        else xt)[ok]
      y1 <- yt[ok]
      if (trace)
        catn("  points2(", x1, ",", y1, ", pch=", pch[ok],
             ", ...)")
      if (plot)
        points2(x1, y1, pch = pch[ok], col = pt.COL[ok], cex = pt.cex[ok],
                bg = pt.bg[ok], lwd = pt.lwd[ok])
    }
    xt <- xt + x.intersp * xchar
    if (plot) {
      if (!is.null(title))
        text2(left + w * title.adj, top - ymax, labels = title,
              adj = c(title.adj, 0), cex = cex, col = title.col)
      text2(xt, yt, labels = legend, adj = adj, cex = cex,
            col = text.col, font = text.font)
    }
    invisible(list(rect = list(w = w, h = h, left = left, top = top),
                   text = list(x = xt, y = yt)))
  }
  
### Plot linegraph with error bars

tiff("Fig. 7_Floristic Quality Index.tiff", width=6, height=5, units="in",res=400, pointsize=8,compression = "lzw")

m <- matrix(c(1,1,2,3),nrow = 2,ncol = 2,byrow = TRUE)
  
layout(mat = m,heights = c(0.7,0.3))
  
par(cex.main = 1.5, mar = c(4, 5, 2, 1) + 0.1, mgp = c(3.5, 1, 0), cex.lab = 1.5, 
      font.lab = 2, cex.axis = 1.5, bty = "n", las = 1)
  x1 <- c(1, 2, 3, 4)
  plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
       ylim = c(5, 10), xlim = c(1, 4), lwd = 1, pch = 5, axes = F, main = "")
  axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
  mtext("Year", side = 1, line = 3, cex = 1.5, font = 2)
  axis(2, pos = 1.2, seq(5, 10,by=1))
  par(las = 0)
  mtext("Floristic Quality Index", side = 2, line = 1.5, cex = 1.5, font = 2)
  x <- c(1.5, 2.5, 3.5)
  
  plot.errbars <- plotsegraph(x, c(FQI2.15.rf, FQI2.16.rf, FQI2.17.rf), 
                              c(FQI2_se.15.rf, FQI2_se.16.rf, FQI2_se.17.rf), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.12, c(FQI2.15.cn, FQI2.16.cn, FQI2.17.cn), 
                              c(FQI2_se.15.cn, FQI2_se.16.cn, FQI2_se.17.cn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.06, c(FQI2.15.cw, FQI2.16.cw, FQI2.17.cw), 
                              c(FQI2_se.15.cw, FQI2_se.16.cw, FQI2_se.17.cw), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.12, c(FQI2.15.fn, FQI2.16.fn, FQI2.17.fn), 
                              c(FQI2_se.15.fn, FQI2_se.16.fn, FQI2_se.17.fn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.06, c(FQI2.15.fw, FQI2.16.fw, FQI2.17.fw), 
                              c(FQI2_se.15.fw, FQI2_se.16.fw, FQI2_se.17.fw), 0.07, color = "black")  #0.07 = wiskwidth
  
  lines(x,      c(FQI2.15.rf, FQI2.16.rf, FQI2.17.rf), lwd = 1, type = "c", lty=1, col=colors()[c(320)])
  lines(x+0.12, c(FQI2.15.cn, FQI2.16.cn, FQI2.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
  lines(x+0.06, c(FQI2.15.cw, FQI2.16.cw, FQI2.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
  lines(x-0.12, c(FQI2.15.fn, FQI2.16.fn, FQI2.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
  lines(x-0.06, c(FQI2.15.fw, FQI2.16.fw, FQI2.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")
  
  points(x,      c(FQI2.15.rf, FQI2.16.rf, FQI2.17.rf), cex = 1.8, lwd = 1, pch = 10)
  points(x+0.12, c(FQI2.15.cn, FQI2.16.cn, FQI2.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg="white")
  points(x+0.06, c(FQI2.15.cw, FQI2.16.cw, FQI2.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
  points(x-0.12, c(FQI2.15.fn, FQI2.16.fn, FQI2.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg="white")
  points(x-0.06, c(FQI2.15.fw, FQI2.16.fw, FQI2.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")
  
  
  
  par(mar=c(0,2,0,1)+0.1)
  plot(1,type="n",axes = F,xlab="",ylab="")
  LEGEND("topleft",pch=c(24,17,10), lty=c(1,2,1), col=c("royalblue","royalblue",colors()[(320)]),pt.bg="white",
         pt.col=c("royalblue","royalblue",1),pt.cex=1.8,lwd=1,seg.len=3.5,bty = "n", cex=1.7, ncol=1,pt.lwd=1,y.intersp=1,x.intersp=0.2,
         legend = c("Cut-stump w/out mulch","Cut-stump w/ mulch", "Reference"))
  
  par(mar=c(0,0,0,1)+0.1)
  plot(1,type="n",axes = F,xlab="",ylab="")
  LEGEND("topleft",pch=c(23,18), lty=c(2,1), col="darkorange",pt.bg="white",
         pt.col="darkorange",pt.cex=1.8,lwd=1,seg.len=3.5,bty = "n", cex=1.7, ncol=1,pt.lwd=1,y.intersp=1,x.intersp=0.2,
         legend = c("MH w/out mulch","MH w/ mulch"))

dev.off()  
