### Analysis of summer herbaceous total cover, S, H', J', and garlic mustard abundance ###

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")

library(lme4)
library(lmerTest)
library(lsmeans)
library(multcomp)
library(psych)
library(vegan)

comm.all<-read.table("Veg Community Cover Values.csv", header=T, sep=',')

nrow(comm.all)
ncol(comm.all)
head(comm.all)

herb.all<-comm.all[,1:103]

herb.all$Mulch<-factor(herb.all$Mulch, levels(herb.all$Mulch)[c(2,1,3)])
  levels(herb.all$Mulch) #ref should be first
herb.all$Treatment<-factor(herb.all$Treatment, levels(herb.all$Treatment)[c(5,1,2,3,4)])
  levels(herb.all$Treatment) #ref should be first
herb.all$Removal<-factor(herb.all$Removal, levels(herb.all$Removal)[c(3,1,2)])
  levels(herb.all$Removal) #ref should be first
  
herb.means<-matrix(data=NA,nrow=(103-6), ncol=15)
  colnames(herb.means)<-c("Ref15","Ref16","Ref17","Cut-15","Cut-16","Cut-17",
                          "Cut+15","Cut+16","Cut+17","Fecon-15","Fecon-16","Fecon-17","Fecon+15","Fecon+16","Fecon+17")
  rownames(herb.means)<-colnames(herb.all)[7:103]
  for(i in 1:nrow(herb.means)){
    herb.means[i,]<-describeBy(herb.all[,i+6],group = list(herb.all$Year,herb.all$Treatment),mat=T)$mean
    
  }
  options(max.print = 10000)
  herb.means
    
 describeBy(cbind.data.frame(herb.all[,1:6],
                  rowSums(cbind.data.frame(herb.all$Unk1.2017.h,herb.all$Unk2017.h, herb.all$Unk2017.h, herb.all$Unk3.2017.h,
                          herb.all$Unk6.2017.h, herb.all$Unk8.2017.h, herb.all$UnkAster10.h, herb.all$UnkAster4.h,
                          herb.all$UnkAster6.h, herb.all$UnkAster8.h, herb.all$UnkAster9.h, herb.all$UnkOppo1.h, herb.all$UnkOppo2.h,
                          herb.all$UnkOrchid.2017.h, herb.all$UnkPolemoniaceae.h, herb.all$UnkRosette1.h, herb.all$UnkRosette2.h)))[,7],
            group = list(herb.all$Year,herb.all$Treatment),mat=T)[,c("mean","se")]
 
 
herb.SE<-matrix(data=NA,nrow=(103-6), ncol=15)
  colnames(herb.SE)<-c("Ref15","Ref16","Ref17","Cut-15","Cut-16","Cut-17",
                          "Cut+15","Cut+16","Cut+17","Fecon-15","Fecon-16","Fecon-17","Fecon+15","Fecon+16","Fecon+17")
  rownames(herb.SE)<-colnames(herb.all)[7:103]
  for(i in 1:nrow(herb.SE)){
    herb.SE[i,]<-describeBy(herb.all[,i+6],group = list(herb.all$Year,herb.all$Treatment),mat=T)$se
    
  }
  options(max.print = 10000)
  herb.SE  
  
  head(herb.all) #last herbaceous species should be Vitis
  
  
herb.15<-subset(herb.all, herb.all$Year=="2015")
nrow(herb.15)
herb.16<-subset(herb.all, herb.all$Year=="2016")
nrow(herb.16)
herb.17<-subset(herb.all, herb.all$Year=="2017")
nrow(herb.17)  

### Total Cover Across All Years ###
head(herb.all) #first 6 columns are describtors
ncol(herb.all) #103 herbaceous species

totals.all<-cbind(herb.all[,1:6],rowSums(herb.all[,7:103]))
colnames(totals.all)<-c("Plot","Site","Year","Treatment","Mulch","Removal","Tot.Cov")
totals.all$Year.rel<-totals.all$Year-2015


totals.15<-subset(totals.all, totals.all$Year=="2015")
  nrow(totals.15)
totals.16<-subset(totals.all, totals.all$Year=="2016")
  nrow(totals.16)
totals.17<-subset(totals.all, totals.all$Year=="2017")
  nrow(totals.17)

  
  
# contrast.matrix <- rbind("Year:Ref vs. Year:Cut-" =  c(0, 0, 0, 0, 0, 0, 1, 0, 0, 0),
#                           "Year:Ref vs. Year:Cut+" =  c(0, 0, 0, 0, 0, 0, 0, 1, 0, 0),
#                           "Year:Ref vs. Year:Fecon-" =  c(0, 0, 0, 0, 0, 0, 0, 0, 1, 0),
#                           "Year:Ref vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1),
#                           "Year:Cut- vs. Year:Cut+" =  c(0, 0, 0, 0, 0, 0, -1, 1, 0, 0),
#                           "Year:Cut- vs. Year:Fecon-" =  c(0, 0, 0, 0, 0, 0, -1, 0, 1, 0),
#                           "Year:Cut- vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, -1, 0, 0, 1),
#                           "Year:Cut+ vs. Year:Fecon-" =  c(0, 0, 0, 0, 0, 0, 0, -1, 1, 0),
#                           "Year:Cut+ vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, 0, -1, 0, 1),
#                           "Year:Fecon- vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, 0, 0, -1, 1))
  
contrast.matrix2<- rbind("Year:Ref vs. 0"=c(0,1,0,0,0,0,0,0,0,0),
                           "Year:Ref vs. Year:Cut-"=c(0, 0, 0, 0, 0, 0, 1, 0, 0, 0),
                           "Year:Ref vs. Year:Fecon+"=c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1),
                           "Year:Cut vs Year:Fecon" = c(0, 0, 0, 0, 0, 0, -0.5, -0.5, 0.5, 0.5),
                           "Year:Unmulched vs Year:Mulched" = c(0, 0, 0, 0, 0, 0, -0.5, 0.5, -0.5, 0.5),
                           "Year:Cut- vs Year:Fecon+" = c(0, 0, 0, 0, 0, 0, -1, 0, 0, 1))
  


  
attach(totals.all)
lm.tot<-lmer(Tot.Cov~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
  plot(lm.tot)
lm.tot.log<-lmer(log(Tot.Cov+1)~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
  str(lm.tot.log)
  plot(lm.tot.log)
  hist(residuals(lm.tot.log))
  
  summary(lm.tot.log)
  anova(lm.tot.log) 

  summary(glht(lm.tot.log,contrast.matrix2))

#no significant comparisons


?glht


describeBy(totals.15,group="Treatment")
describeBy(totals.16,group="Treatment")
describeBy(totals.17,group="Treatment")

tot.means <- data.frame(matrix(vector(), 5, 3,
                               dimnames=list(c(), c("2015", "2016", "2017"))),
                        stringsAsFactors=F)
rownames(tot.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
tot.means[,1]<-c(describeBy(totals.15,group="Treatment")$`Ref`["Tot.Cov","mean"],
                 describeBy(totals.15,group="Treatment")$`Cut-`["Tot.Cov","mean"],
                 describeBy(totals.15,group="Treatment")$`Cut+`["Tot.Cov","mean"],
                 describeBy(totals.15,group="Treatment")$`Fecon-`["Tot.Cov","mean"],
                 describeBy(totals.15,group="Treatment")$`Fecon+`["Tot.Cov","mean"])
tot.means[,2]<-c(describeBy(totals.16,group="Treatment")$`Ref`["Tot.Cov","mean"],
                 describeBy(totals.16,group="Treatment")$`Cut-`["Tot.Cov","mean"],
                 describeBy(totals.16,group="Treatment")$`Cut+`["Tot.Cov","mean"],
                 describeBy(totals.16,group="Treatment")$`Fecon-`["Tot.Cov","mean"],
                 describeBy(totals.16,group="Treatment")$`Fecon+`["Tot.Cov","mean"])
tot.means[,3]<-c(describeBy(totals.17,group="Treatment")$`Ref`["Tot.Cov","mean"],
                 describeBy(totals.17,group="Treatment")$`Cut-`["Tot.Cov","mean"],
                 describeBy(totals.17,group="Treatment")$`Cut+`["Tot.Cov","mean"],
                 describeBy(totals.17,group="Treatment")$`Fecon-`["Tot.Cov","mean"],
                 describeBy(totals.17,group="Treatment")$`Fecon+`["Tot.Cov","mean"])

tot.means


m.15.rf<-tot.means[1,1]
m.15.cn<-tot.means[2,1]
m.15.cw<-tot.means[3,1]
m.15.fn<-tot.means[4,1]
m.15.fw<-tot.means[5,1]
m.16.rf<-tot.means[1,2]
m.16.cn<-tot.means[2,2]
m.16.cw<-tot.means[3,2]
m.16.fn<-tot.means[4,2]
m.16.fw<-tot.means[5,2]
m.17.rf<-tot.means[1,3]
m.17.cn<-tot.means[2,3]
m.17.cw<-tot.means[3,3]
m.17.fn<-tot.means[4,3]
m.17.fw<-tot.means[5,3]

tot.se <- data.frame(matrix(vector(), 5, 3,
                               dimnames=list(c(), c("2015", "2016", "2017"))),
                        stringsAsFactors=F)
rownames(tot.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
tot.se[,1]<-c(describeBy(totals.15,group="Treatment")$`Ref`["Tot.Cov","se"],
                 describeBy(totals.15,group="Treatment")$`Cut-`["Tot.Cov","se"],
                 describeBy(totals.15,group="Treatment")$`Cut+`["Tot.Cov","se"],
                 describeBy(totals.15,group="Treatment")$`Fecon-`["Tot.Cov","se"],
                 describeBy(totals.15,group="Treatment")$`Fecon+`["Tot.Cov","se"])
tot.se[,2]<-c(describeBy(totals.16,group="Treatment")$`Ref`["Tot.Cov","se"],
                 describeBy(totals.16,group="Treatment")$`Cut-`["Tot.Cov","se"],
                 describeBy(totals.16,group="Treatment")$`Cut+`["Tot.Cov","se"],
                 describeBy(totals.16,group="Treatment")$`Fecon-`["Tot.Cov","se"],
                 describeBy(totals.16,group="Treatment")$`Fecon+`["Tot.Cov","se"])
tot.se[,3]<-c(describeBy(totals.17,group="Treatment")$`Ref`["Tot.Cov","se"],
                 describeBy(totals.17,group="Treatment")$`Cut-`["Tot.Cov","se"],
                 describeBy(totals.17,group="Treatment")$`Cut+`["Tot.Cov","se"],
                 describeBy(totals.17,group="Treatment")$`Fecon-`["Tot.Cov","se"],
                 describeBy(totals.17,group="Treatment")$`Fecon+`["Tot.Cov","se"])

se.15.rf<-tot.se[1,1]
se.15.cn<-tot.se[2,1]
se.15.cw<-tot.se[3,1]
se.15.fn<-tot.se[4,1]
se.15.fw<-tot.se[5,1]
se.16.rf<-tot.se[1,2]
se.16.cn<-tot.se[2,2]
se.16.cw<-tot.se[3,2]
se.16.fn<-tot.se[4,2]
se.16.fw<-tot.se[5,2]
se.17.rf<-tot.se[1,3]
se.17.cn<-tot.se[2,3]
se.17.cw<-tot.se[3,3]
se.17.fn<-tot.se[4,3]
se.17.fw<-tot.se[5,3]

detach(totals.all)

### Calculate Diversity Indices ###
library(vegan)

herb15.sp<-herb.15[,7:103]
S15<-as.vector(specnumber(herb15.sp, herb.15[,1]))
S.15<-cbind(herb.15[,1:6],S15)
colnames(S.15)[7]<-"S"
H15<-as.vector(diversity(herb15.sp, index = "shannon"))
H.15<-cbind(herb.15[,1:6],H15)
colnames(H.15)[7]<-"H"
J15<-H15/log(S15)    
J.15<-cbind(herb.15[,1:6],J15)    
colnames(J.15)[7]<-"J"

herb16.sp<-herb.16[,7:103]
S16<-as.vector(specnumber(herb16.sp, herb.16[,1]))
S.16<-cbind(herb.16[,1:6],S16)
colnames(S.16)[7]<-"S"
H16<-as.vector(diversity(herb16.sp, index = "shannon"))
H.16<-cbind(herb.16[,1:6],H16)
colnames(H.16)[7]<-"H"
J16<-H16/log(S16)    
J.16<-cbind(herb.16[,1:6],J16)
colnames(J.16)[7]<-"J"

herb17.sp<-herb.17[,7:103]
S17<-as.vector(specnumber(herb17.sp, herb.17[,1]))
S.17<-cbind(herb.17[,1:6],S17)
colnames(S.17)[7]<-"S"
H17<-as.vector(diversity(herb17.sp, index = "shannon"))
H.17<-cbind(herb.17[,1:6],H17)
colnames(H.17)[7]<-"H"
J17<-H17/log(S17)    
J.17<-cbind(herb.17[,1:6],J17)
colnames(J.17)[7]<-"J"

richness<-rbind(S.15,S.16,S.17)
  richness$Year.rel<-richness$Year-2015
diversity<-rbind(H.15,H.16,H.17)
  diversity$Year.rel<-diversity$Year-2015
evenness<-rbind(J.15, J.16, J.17)
  evenness$Year.rel<-evenness$Year-2015


attach(richness)
lm.S<-lmer(S~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
  plot(lm.S)
  hist(residuals(lm.S))

  summary(lm.S)
  anova(lm.S)
  summary(glht(lm.S,contrast.matrix2))

#### linegraph ###

S.means <- data.frame(matrix(vector(), 5, 3,
                             dimnames=list(c(), c("2015", "2016", "2017"))),
                      stringsAsFactors=F)
rownames(S.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
S.means[,1]<-c(describeBy(S.15,group="Treatment")$`Ref`["S","mean"],
               describeBy(S.15,group="Treatment")$`Cut-`["S","mean"],
               describeBy(S.15,group="Treatment")$`Cut+`["S","mean"],
               describeBy(S.15,group="Treatment")$`Fecon-`["S","mean"],
               describeBy(S.15,group="Treatment")$`Fecon+`["S","mean"])
S.means[,2]<-c(describeBy(S.16,group="Treatment")$`Ref`["S","mean"],
               describeBy(S.16,group="Treatment")$`Cut-`["S","mean"],
               describeBy(S.16,group="Treatment")$`Cut+`["S","mean"],
               describeBy(S.16,group="Treatment")$`Fecon-`["S","mean"],
               describeBy(S.16,group="Treatment")$`Fecon+`["S","mean"])
S.means[,3]<-c(describeBy(S.17,group="Treatment")$`Ref`["S","mean"],
               describeBy(S.17,group="Treatment")$`Cut-`["S","mean"],
               describeBy(S.17,group="Treatment")$`Cut+`["S","mean"],
               describeBy(S.17,group="Treatment")$`Fecon-`["S","mean"],
               describeBy(S.17,group="Treatment")$`Fecon+`["S","mean"])

S_m.15.rf<-S.means[1,1]
S_m.15.cn<-S.means[2,1]
S_m.15.cw<-S.means[3,1]
S_m.15.fn<-S.means[4,1]
S_m.15.fw<-S.means[5,1]
S_m.16.rf<-S.means[1,2]
S_m.16.cn<-S.means[2,2]
S_m.16.cw<-S.means[3,2]
S_m.16.fn<-S.means[4,2]
S_m.16.fw<-S.means[5,2]
S_m.17.rf<-S.means[1,3]
S_m.17.cn<-S.means[2,3]
S_m.17.cw<-S.means[3,3]
S_m.17.fn<-S.means[4,3]
S_m.17.fw<-S.means[5,3]



S.se <- data.frame(matrix(vector(), 5, 3,
                            dimnames=list(c(), c("2015", "2016", "2017"))),
                     stringsAsFactors=F)
rownames(S.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
S.se[,1]<-c(describeBy(S.15,group="Treatment")$`Ref`["S","se"],
              describeBy(S.15,group="Treatment")$`Cut-`["S","se"],
              describeBy(S.15,group="Treatment")$`Cut+`["S","se"],
              describeBy(S.15,group="Treatment")$`Fecon-`["S","se"],
              describeBy(S.15,group="Treatment")$`Fecon+`["S","se"])
S.se[,2]<-c(describeBy(S.16,group="Treatment")$`Ref`["S","se"],
              describeBy(S.16,group="Treatment")$`Cut-`["S","se"],
              describeBy(S.16,group="Treatment")$`Cut+`["S","se"],
              describeBy(S.16,group="Treatment")$`Fecon-`["S","se"],
              describeBy(S.16,group="Treatment")$`Fecon+`["S","se"])
S.se[,3]<-c(describeBy(S.17,group="Treatment")$`Ref`["S","se"],
              describeBy(S.17,group="Treatment")$`Cut-`["S","se"],
              describeBy(S.17,group="Treatment")$`Cut+`["S","se"],
              describeBy(S.17,group="Treatment")$`Fecon-`["S","se"],
              describeBy(S.17,group="Treatment")$`Fecon+`["S","se"])

S_se.15.rf<-S.se[1,1]
S_se.15.cn<-S.se[2,1]
S_se.15.cw<-S.se[3,1]
S_se.15.fn<-S.se[4,1]
S_se.15.fw<-S.se[5,1]
S_se.16.rf<-S.se[1,2]
S_se.16.cn<-S.se[2,2]
S_se.16.cw<-S.se[3,2]
S_se.16.fn<-S.se[4,2]
S_se.16.fw<-S.se[5,2]
S_se.17.rf<-S.se[1,3]
S_se.17.cn<-S.se[2,3]
S_se.17.cw<-S.se[3,3]
S_se.17.fn<-S.se[4,3]
S_se.17.fw<-S.se[5,3]

detach(richness)  

attach(diversity)
lm.H<-lmer(H~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
  plot(lm.H)
  hist(residuals(lm.H))
  
  summary(lm.H)
  anova(lm.H)
  summary(glht(lm.H,contrast.matrix2))


#### linegraph ###
H.means <- data.frame(matrix(vector(), 5, 3,
                             dimnames=list(c(), c("2015", "2016", "2017"))),
                      stringsAsFactors=F)
rownames(H.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
H.means[,1]<-c(describeBy(H.15,group="Treatment")$`Ref`["H","mean"],
               describeBy(H.15,group="Treatment")$`Cut-`["H","mean"],
               describeBy(H.15,group="Treatment")$`Cut+`["H","mean"],
               describeBy(H.15,group="Treatment")$`Fecon-`["H","mean"],
               describeBy(H.15,group="Treatment")$`Fecon+`["H","mean"])
H.means[,2]<-c(describeBy(H.16,group="Treatment")$`Ref`["H","mean"],
               describeBy(H.16,group="Treatment")$`Cut-`["H","mean"],
               describeBy(H.16,group="Treatment")$`Cut+`["H","mean"],
               describeBy(H.16,group="Treatment")$`Fecon-`["H","mean"],
               describeBy(H.16,group="Treatment")$`Fecon+`["H","mean"])
H.means[,3]<-c(describeBy(H.17,group="Treatment")$`Ref`["H","mean"],
               describeBy(H.17,group="Treatment")$`Cut-`["H","mean"],
               describeBy(H.17,group="Treatment")$`Cut+`["H","mean"],
               describeBy(H.17,group="Treatment")$`Fecon-`["H","mean"],
               describeBy(H.17,group="Treatment")$`Fecon+`["H","mean"])


H.se <- data.frame(matrix(vector(), 5, 3,
                          dimnames=list(c(), c("2015", "2016", "2017"))),
                   stringsAsFactors=F)
rownames(H.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
H.se[,1]<-c(describeBy(H.15,group="Treatment")$`Ref`["H","se"],
            describeBy(H.15,group="Treatment")$`Cut-`["H","se"],
            describeBy(H.15,group="Treatment")$`Cut+`["H","se"],
            describeBy(H.15,group="Treatment")$`Fecon-`["H","se"],
            describeBy(H.15,group="Treatment")$`Fecon+`["H","se"])
H.se[,2]<-c(describeBy(H.16,group="Treatment")$`Ref`["H","se"],
            describeBy(H.16,group="Treatment")$`Cut-`["H","se"],
            describeBy(H.16,group="Treatment")$`Cut+`["H","se"],
            describeBy(H.16,group="Treatment")$`Fecon-`["H","se"],
            describeBy(H.16,group="Treatment")$`Fecon+`["H","se"])
H.se[,3]<-c(describeBy(H.17,group="Treatment")$`Ref`["H","se"],
            describeBy(H.17,group="Treatment")$`Cut-`["H","se"],
            describeBy(H.17,group="Treatment")$`Cut+`["H","se"],
            describeBy(H.17,group="Treatment")$`Fecon-`["H","se"],
            describeBy(H.17,group="Treatment")$`Fecon+`["H","se"])

H_m.15.rf<-H.means[1,1]
H_m.15.cn<-H.means[2,1]
H_m.15.cw<-H.means[3,1]
H_m.15.fn<-H.means[4,1]
H_m.15.fw<-H.means[5,1]
H_m.16.rf<-H.means[1,2]
H_m.16.cn<-H.means[2,2]
H_m.16.cw<-H.means[3,2]
H_m.16.fn<-H.means[4,2]
H_m.16.fw<-H.means[5,2]
H_m.17.rf<-H.means[1,3]
H_m.17.cn<-H.means[2,3]
H_m.17.cw<-H.means[3,3]
H_m.17.fn<-H.means[4,3]
H_m.17.fw<-H.means[5,3]


H_se.15.rf<-H.se[1,1]
H_se.15.cn<-H.se[2,1]
H_se.15.cw<-H.se[3,1]
H_se.15.fn<-H.se[4,1]
H_se.15.fw<-H.se[5,1]
H_se.16.rf<-H.se[1,2]
H_se.16.cn<-H.se[2,2]
H_se.16.cw<-H.se[3,2]
H_se.16.fn<-H.se[4,2]
H_se.16.fw<-H.se[5,2]
H_se.17.rf<-H.se[1,3]
H_se.17.cn<-H.se[2,3]
H_se.17.cw<-H.se[3,3]
H_se.17.fn<-H.se[4,3]
H_se.17.fw<-H.se[5,3]

detach(diversity)

attach(evenness)  

lm.J<-lmer(J~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
  plot(lm.J)
  hist(residuals(lm.J)) #leptykurtic

lm.J.log<-lmer(log(J+1)~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
  plot(lm.J.log) #log transformation doesn't help
  hist(residuals(lm.J.log)) 
  
plot(J, col=as.numeric(Site), pch=as.numeric(Treatment)) #issue is evenness values of 0 at many PWA plots in 2015

evenness.noPWA<-subset(evenness, Site!="W1")
  detach(evenness)
  attach(evenness.noPWA)

lm.J.noPWA<-lmer(J~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
  plot(lm.J.noPWA)
  hist(residuals(lm.J.noPWA)) #left skew
  
lm.J.noPWA.log<-lmer(log(J+1)~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
  plot(lm.J.noPWA.log)
  hist(residuals(lm.J.noPWA.log)) #not helpful
  
lm.J.noPWA.2<-lmer(J^2~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
  plot(lm.J.noPWA.2)
  hist(residuals(lm.J.noPWA.2)) #good
  
  anova(lm.J.noPWA.2)
  summary(lm.J.noPWA.2)

# evenness means and se for figures  
J.means <- data.frame(matrix(vector(), 5, 3,
                             dimnames=list(c(), c("2015", "2016", "2017"))),
                      stringsAsFactors=F)
rownames(J.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
J.means[,1]<-c(describeBy(J.15,group="Treatment")$`Ref`["J","mean"],
               describeBy(J.15,group="Treatment")$`Cut-`["J","mean"],
               describeBy(J.15,group="Treatment")$`Cut+`["J","mean"],
               describeBy(J.15,group="Treatment")$`Fecon-`["J","mean"],
               describeBy(J.15,group="Treatment")$`Fecon+`["J","mean"])
J.means[,2]<-c(describeBy(J.16,group="Treatment")$`Ref`["J","mean"],
               describeBy(J.16,group="Treatment")$`Cut-`["J","mean"],
               describeBy(J.16,group="Treatment")$`Cut+`["J","mean"],
               describeBy(J.16,group="Treatment")$`Fecon-`["J","mean"],
               describeBy(J.16,group="Treatment")$`Fecon+`["J","mean"])
J.means[,3]<-c(describeBy(J.17,group="Treatment")$`Ref`["J","mean"],
               describeBy(J.17,group="Treatment")$`Cut-`["J","mean"],
               describeBy(J.17,group="Treatment")$`Cut+`["J","mean"],
               describeBy(J.17,group="Treatment")$`Fecon-`["J","mean"],
               describeBy(J.17,group="Treatment")$`Fecon+`["J","mean"])

J.se <- data.frame(matrix(vector(), 5, 3,
                          dimnames=list(c(), c("2015", "2016", "2017"))),
                   stringsAsFactors=F)
rownames(J.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
J.se[,1]<-c(describeBy(J.15,group="Treatment")$`Ref`["J","se"],
            describeBy(J.15,group="Treatment")$`Cut-`["J","se"],
            describeBy(J.15,group="Treatment")$`Cut+`["J","se"],
            describeBy(J.15,group="Treatment")$`Fecon-`["J","se"],
            describeBy(J.15,group="Treatment")$`Fecon+`["J","se"])
J.se[,2]<-c(describeBy(J.16,group="Treatment")$`Ref`["J","se"],
            describeBy(J.16,group="Treatment")$`Cut-`["J","se"],
            describeBy(J.16,group="Treatment")$`Cut+`["J","se"],
            describeBy(J.16,group="Treatment")$`Fecon-`["J","se"],
            describeBy(J.16,group="Treatment")$`Fecon+`["J","se"])
J.se[,3]<-c(describeBy(J.17,group="Treatment")$`Ref`["J","se"],
            describeBy(J.17,group="Treatment")$`Cut-`["J","se"],
            describeBy(J.17,group="Treatment")$`Cut+`["J","se"],
            describeBy(J.17,group="Treatment")$`Fecon-`["J","se"],
            describeBy(J.17,group="Treatment")$`Fecon+`["J","se"])


J_m.15.rf<-J.means[1,1]
J_m.15.cn<-J.means[2,1]
J_m.15.cw<-J.means[3,1]
J_m.15.fn<-J.means[4,1]
J_m.15.fw<-J.means[5,1]
J_m.16.rf<-J.means[1,2]
J_m.16.cn<-J.means[2,2]
J_m.16.cw<-J.means[3,2]
J_m.16.fn<-J.means[4,2]
J_m.16.fw<-J.means[5,2]
J_m.17.rf<-J.means[1,3]
J_m.17.cn<-J.means[2,3]
J_m.17.cw<-J.means[3,3]
J_m.17.fn<-J.means[4,3]
J_m.17.fw<-J.means[5,3]


J_se.15.rf<-J.se[1,1]
J_se.15.cn<-J.se[2,1]
J_se.15.cw<-J.se[3,1]
J_se.15.fn<-J.se[4,1]
J_se.15.fw<-J.se[5,1]
J_se.16.rf<-J.se[1,2]
J_se.16.cn<-J.se[2,2]
J_se.16.cw<-J.se[3,2]
J_se.16.fn<-J.se[4,2]
J_se.16.fw<-J.se[5,2]
J_se.17.rf<-J.se[1,3]
J_se.17.cn<-J.se[2,3]
J_se.17.cw<-J.se[3,3]
J_se.17.fn<-J.se[4,3]
J_se.17.fw<-J.se[5,3]

detach(evenness)
  
  Tot.Diff<-totals.17$Tot.Cov-totals.15$Tot.Cov
  S.Diff<-S17-S15
    H.Diff<-H17-H15
    J.Diff<-J17-J15
    removal.ind<-rep(c(rep("Removal",16),rep("Ref",8)),4)
  
  param.change<-cbind.data.frame(removal.ind, Tot.Diff, S.Diff, H.Diff, J.Diff)
  describeBy(param.change, group=tot.change$removal.ind)
  
  
  
#### Figure
  
  ### Legend function allowing for different point and line colors
  LEGEND <- function (x, y = NULL, legend, fill = NULL, 
                      col = par("col"), pt.col=col, line.col=col,
                      border = "black", lty, lwd, pch, angle = 45, density = NULL,
                      bty = "o", bg = par("bg"), box.lwd = par("lwd"), box.lty = par("lty"),
                      box.col = par("fg"), pt.bg = NA, cex = 1, pt.cex = cex, pt.lwd = lwd,
                      xjust = 0, yjust = 1, x.intersp = 1, y.intersp = 1, adj = c(0,
                                                                                  0.5), text.width = NULL, text.col = par("col"), text.font = NULL,
                      merge = do.lines && has.pch, trace = FALSE, plot = TRUE,
                      ncol = 1, horiz = FALSE, title = NULL, inset = 0, xpd, title.col = text.col,
                      title.adj = 0.5, seg.len = 2)
  {
    if (missing(legend) && !missing(y) && (is.character(y) ||
                                           is.expression(y))) {
      legend <- y
      y <- NULL
    }
    mfill <- !missing(fill) || !missing(density)
    if (!missing(xpd)) {
      op <- par("xpd")
      on.exit(par(xpd = op))
      par(xpd = xpd)
    }
    title <- as.graphicsAnnot(title)
    if (length(title) > 1)
      stop("invalid 'title'")
    legend <- as.graphicsAnnot(legend)
    n.leg <- if (is.call(legend))
      1
    else length(legend)
    if (n.leg == 0)
      stop("'legend' is of length 0")
    auto <- if (is.character(x))
      match.arg(x, c("bottomright", "bottom", "bottomleft",
                     "left", "topleft", "top", "topright", "right", "center"))
    else NA
    if (is.na(auto)) {
      xy <- xy.coords(x, y)
      x <- xy$x
      y <- xy$y
      nx <- length(x)
      if (nx < 1 || nx > 2)
        stop("invalid coordinate lengths")
    }
    else nx <- 0
    xlog <- par("xlog")
    ylog <- par("ylog")
    rect2 <- function(left, top, dx, dy, density = NULL, angle,
                      ...) {
      r <- left + dx
      if (xlog) {
        left <- 10^left
        r <- 10^r
      }
      b <- top - dy
      if (ylog) {
        top <- 10^top
        b <- 10^b
      }
      rect(left, top, r, b, angle = angle, density = density,
           ...)
    }
    segments2 <- function(x1, y1, dx, dy, ...) {
      x2 <- x1 + dx
      if (xlog) {
        x1 <- 10^x1
        x2 <- 10^x2
      }
      y2 <- y1 + dy
      if (ylog) {
        y1 <- 10^y1
        y2 <- 10^y2
      }
      segments(x1, y1, x2, y2, ...)
    }
    points2 <- function(x, y, ...) {
      if (xlog)
        x <- 10^x
      if (ylog)
        y <- 10^y
      points(x, y, ...)
    }
    text2 <- function(x, y, ...) {
      if (xlog)
        x <- 10^x
      if (ylog)
        y <- 10^y
      text(x, y, ...)
    }
    if (trace)
      catn <- function(...) do.call("cat", c(lapply(list(...),
                                                    formatC), list("\n")))
    cin <- par("cin")
    Cex <- cex * par("cex")
    if (is.null(text.width))
      text.width <- max(abs(strwidth(legend, units = "user",
                                     cex = cex, font = text.font)))
    else if (!is.numeric(text.width) || text.width < 0)
      stop("'text.width' must be numeric, >= 0")
    xc <- Cex * xinch(cin[1L], warn.log = FALSE)
    yc <- Cex * yinch(cin[2L], warn.log = FALSE)
    if (xc < 0)
      text.width <- -text.width
    xchar <- xc
    xextra <- 0
    yextra <- yc * (y.intersp - 1)
    ymax <- yc * max(1, strheight(legend, units = "user", cex = cex)/yc)
    ychar <- yextra + ymax
    if (trace)
      catn("  xchar=", xchar, "; (yextra,ychar)=", c(yextra,
                                                     ychar))
    if (mfill) {
      xbox <- xc * 0.8
      ybox <- yc * 0.5
      dx.fill <- xbox
    }
    do.lines <- (!missing(lty) && (is.character(lty) || any(lty >
                                                              0))) || !missing(lwd)
    n.legpercol <- if (horiz) {
      if (ncol != 1)
        warning(gettextf("horizontal specification overrides: Number of columns := %d",
                         n.leg), domain = NA)
      ncol <- n.leg
      1
    }
    else ceiling(n.leg/ncol)
    has.pch <- !missing(pch) && length(pch) > 0
    if (do.lines) {
      x.off <- if (merge)
        -0.7
      else 0
    }
    else if (merge)
      warning("'merge = TRUE' has no effect when no line segments are drawn")
    if (has.pch) {
      if (is.character(pch) && !is.na(pch[1L]) && nchar(pch[1L],
                                                        type = "c") > 1) {
        if (length(pch) > 1)
          warning("not using pch[2..] since pch[1L] has multiple chars")
        np <- nchar(pch[1L], type = "c")
        pch <- substr(rep.int(pch[1L], np), 1L:np, 1L:np)
      }
      if (!is.character(pch))
        pch <- as.integer(pch)
    }
    if (is.na(auto)) {
      if (xlog)
        x <- log10(x)
      if (ylog)
        y <- log10(y)
    }
    if (nx == 2) {
      x <- sort(x)
      y <- sort(y)
      left <- x[1L]
      top <- y[2L]
      w <- diff(x)
      h <- diff(y)
      w0 <- w/ncol
      x <- mean(x)
      y <- mean(y)
      if (missing(xjust))
        xjust <- 0.5
      if (missing(yjust))
        yjust <- 0.5
    }
    else {
      h <- (n.legpercol + (!is.null(title))) * ychar + yc
      w0 <- text.width + (x.intersp + 1) * xchar
      if (mfill)
        w0 <- w0 + dx.fill
      if (do.lines)
        w0 <- w0 + (seg.len + x.off) * xchar
      w <- ncol * w0 + 0.5 * xchar
      if (!is.null(title) && (abs(tw <- strwidth(title, units = "user",
                                                 cex = cex) + 0.5 * xchar)) > abs(w)) {
        xextra <- (tw - w)/2
        w <- tw
      }
      if (is.na(auto)) {
        left <- x - xjust * w
        top <- y + (1 - yjust) * h
      }
      else {
        usr <- par("usr")
        inset <- rep_len(inset, 2)
        insetx <- inset[1L] * (usr[2L] - usr[1L])
        left <- switch(auto, bottomright = , topright = ,
                       right = usr[2L] - w - insetx, bottomleft = ,
                       left = , topleft = usr[1L] + insetx, bottom = ,
                       top = , center = (usr[1L] + usr[2L] - w)/2)
        insety <- inset[2L] * (usr[4L] - usr[3L])
        top <- switch(auto, bottomright = , bottom = , bottomleft = usr[3L] +
                        h + insety, topleft = , top = , topright = usr[4L] -
                        insety, left = , right = , center = (usr[3L] +
                                                               usr[4L] + h)/2)
      }
    }
    if (plot && bty != "n") {
      if (trace)
        catn("  rect2(", left, ",", top, ", w=", w, ", h=",
             h, ", ...)", sep = "")
      rect2(left, top, dx = w, dy = h, col = bg, density = NULL,
            lwd = box.lwd, lty = box.lty, border = box.col)
    }
    xt <- left + xchar + xextra + (w0 * rep.int(0:(ncol - 1),
                                                rep.int(n.legpercol, ncol)))[1L:n.leg]
    yt <- top - 0.5 * yextra - ymax - (rep.int(1L:n.legpercol,
                                               ncol)[1L:n.leg] - 1 + (!is.null(title))) * ychar
    if (mfill) {
      if (plot) {
        if (!is.null(fill))
          fill <- rep_len(fill, n.leg)
        rect2(left = xt, top = yt + ybox/2, dx = xbox, dy = ybox,
              col = fill, density = density, angle = angle,
              border = border)
      }
      xt <- xt + dx.fill
    }
    if (plot && (has.pch || do.lines)) {
      pt.COL <- rep_len(pt.col, n.leg)
      line.COL <- rep_len(line.col, n.leg)
    }
    if (missing(lwd) || is.null(lwd))
      lwd <- par("lwd")
    if (do.lines) {
      if (missing(lty) || is.null(lty))
        lty <- 1
      lty <- rep_len(lty, n.leg)
      lwd <- rep_len(lwd, n.leg)
      ok.l <- !is.na(lty) & (is.character(lty) | lty > 0) &
        !is.na(lwd)
      if (trace)
        catn("  segments2(", xt[ok.l] + x.off * xchar, ",",
             yt[ok.l], ", dx=", seg.len * xchar, ", dy=0, ...)")
      if (plot)
        segments2(xt[ok.l] + x.off * xchar, yt[ok.l], dx = seg.len *
                    xchar, dy = 0, lty = lty[ok.l], lwd = lwd[ok.l],
                  col = line.COL[ok.l])
      xt <- xt + (seg.len + x.off) * xchar
    }
    if (has.pch) {
      pch <- rep_len(pch, n.leg)
      pt.bg <- rep_len(pt.bg, n.leg)
      pt.cex <- rep_len(pt.cex, n.leg)
      pt.lwd <- rep_len(pt.lwd, n.leg)
      ok <- !is.na(pch)
      if (!is.character(pch)) {
        ok <- ok & (pch >= 0 | pch <= -32)
      }
      else {
        ok <- ok & nzchar(pch)
      }
      x1 <- (if (merge && do.lines)
        xt - (seg.len/2) * xchar
        else xt)[ok]
      y1 <- yt[ok]
      if (trace)
        catn("  points2(", x1, ",", y1, ", pch=", pch[ok],
             ", ...)")
      if (plot)
        points2(x1, y1, pch = pch[ok], col = pt.COL[ok], cex = pt.cex[ok],
                bg = pt.bg[ok], lwd = pt.lwd[ok])
    }
    xt <- xt + x.intersp * xchar
    if (plot) {
      if (!is.null(title))
        text2(left + w * title.adj, top - ymax, labels = title,
              adj = c(title.adj, 0), cex = cex, col = title.col)
      text2(xt, yt, labels = legend, adj = adj, cex = cex,
            col = text.col, font = text.font)
    }
    invisible(list(rect = list(w = w, h = h, left = left, top = top),
                   text = list(x = xt, y = yt)))
  }
  ###################
  

  plotsegraph <- function(loc, value, sterr, wiskwidth, color = "grey", linewidth = 1) {
    
    w <- wiskwidth/2
    segments(x0 = loc, x1 = loc, y0 = value - sterr, y1 = value + sterr, col = color, 
             lwd = linewidth)
    segments(x0 = loc - w, x1 = loc + w, y0 = value + sterr, y1 = value + sterr, 
             col = color, lwd = linewidth)  # upper whiskers
    segments(x0 = loc - w, x1 = loc + w, y0 = value - sterr, y1 = value - sterr, 
             col = color, lwd = linewidth)  # lower whiskers
  }

### plot start
setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Figures")
  
tiff("Fig. 6_Herbaceous Abundance and Diversity.tiff", height = 7.5, width = 6, units = "in", compression = "lzw", res = 400, pointsize = 11, bg = NA)  
  m <- matrix(c(1,2,3,4,5,6),nrow = 3,ncol = 2,byrow = TRUE)
  
  layout(mat = m,heights = c(1,1,1,1,0.5,0.5))
  
  
  par(cex.main = 1.5, mar = c(4, 4, 3, 0) + 0.1, mgp = c(3.5, 1, 0), cex.lab = 1.3, 
      font.lab = 2, cex.axis = 1, bty = "n", las = 1)
  
  x1 <- c(1, 2, 3, 4)
  
#Total Cover
  plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
       ylim = c(0, 18), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  
  mtext("(a)",side = 3,line=1.2,cex=1,font=1, adj = 0)
  axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
  #mtext("Year", side = 1, line = 4, cex = 1.8, font = 2)
  axis(2, pos = 1.2, seq(0,18,by=2), las=1)
  par(las = 0)
  mtext("Percent Cover", side = 2, line = 1.5, cex = 1, font = 1)
  x <- c(1.5, 2.5, 3.5) 
  
  plot.errbars <- plotsegraph(x, c(m.15.rf, m.16.rf, m.17.rf), 
                              c(se.15.rf, se.16.rf, se.17.rf), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.12, c(m.15.cn, m.16.cn, m.17.cn), 
                              c(se.15.cn, se.16.cn, se.17.cn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.06, c(m.15.cw, m.16.cw, m.17.cw), 
                              c(se.15.cw, se.16.cw, se.17.cw), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.12, c(m.15.fn, m.16.fn, m.17.fn), 
                              c(se.15.fn, se.16.fn, se.17.fn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.06, c(m.15.fw, m.16.fw, m.17.fw), 
                              c(se.15.fw, se.16.fw, se.17.fw), 0.07, color = "black")  #0.07 = wiskwidth
  
  lines(x,      c(m.15.rf, m.16.rf, m.17.rf), lwd = 1, type = "c", lty=1,col=colors()[c(320)])
  lines(x+0.12, c(m.15.cn, m.16.cn, m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
  lines(x+0.06, c(m.15.cw, m.16.cw, m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
  lines(x-0.12, c(m.15.fn, m.16.fn, m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
  lines(x-0.06, c(m.15.fw, m.16.fw, m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")
  
  points(x,      c(m.15.rf, m.16.rf, m.17.rf), cex = 1.8, lwd = 1, pch = 10)
  points(x+0.12, c(m.15.cn, m.16.cn, m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg = "white")
  points(x+0.06, c(m.15.cw, m.16.cw, m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
  points(x-0.12, c(m.15.fn, m.16.fn, m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg = "white")
  points(x-0.06, c(m.15.fw, m.16.fw, m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")
  
#Richness
  plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
       ylim = c(0, 18), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  #Richness
  mtext("(b)",side = 3,line=1.2,cex=1,font=1, adj = 0)
  axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
  #mtext("Year", side = 1, line = 4, cex = 1.8, font = 2)
  axis(2, pos = 1.2, seq(0,18,by=3), las=1)
  par(las = 0)
  mtext("Richness (S)", side = 2, line = 1.5, cex = 1, font = 1)
  x <- c(1.5, 2.5, 3.5)
  
  plot.errbars <- plotsegraph(x, c(S_m.15.rf, S_m.16.rf, S_m.17.rf), 
                              c(S_se.15.rf, S_se.16.rf, S_se.17.rf), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.12, c(S_m.15.cn, S_m.16.cn, S_m.17.cn), 
                              c(S_se.15.cn, S_se.16.cn, S_se.17.cn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.06, c(S_m.15.cw, S_m.16.cw, S_m.17.cw), 
                              c(S_se.15.cw, S_se.16.cw, S_se.17.cw), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.12, c(S_m.15.fn, S_m.16.fn, S_m.17.fn), 
                              c(S_se.15.fn, S_se.16.fn, S_se.17.fn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.06, c(S_m.15.fw, S_m.16.fw, S_m.17.fw), 
                              c(S_se.15.fw, S_se.16.fw, S_se.17.fw), 0.07, color = "black")  #0.07 = wiskwidth
  
  lines(x,      c(S_m.15.rf, S_m.16.rf, S_m.17.rf), lwd = 1, type = "c", lty=1,col=colors()[c(320)])
  lines(x+0.12, c(S_m.15.cn, S_m.16.cn, S_m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
  lines(x+0.06, c(S_m.15.cw, S_m.16.cw, S_m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
  lines(x-0.12, c(S_m.15.fn, S_m.16.fn, S_m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
  lines(x-0.06, c(S_m.15.fw, S_m.16.fw, S_m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")
  
  points(x,      c(S_m.15.rf, S_m.16.rf, S_m.17.rf), cex = 1.8, lwd = 1, pch = 10)
  points(x+0.12, c(S_m.15.cn, S_m.16.cn, S_m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg = "white")
  points(x+0.06, c(S_m.15.cw, S_m.16.cw, S_m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
  points(x-0.12, c(S_m.15.fn, S_m.16.fn, S_m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg = "white")
  points(x-0.06, c(S_m.15.fw, S_m.16.fw, S_m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")
  
  #Diversity
  plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
       ylim = c(0, 2.5), xlim = c(1, 4), lwd = 1, pch = 5, axes = F, main = "")  #Richness
  mtext("(c)",side = 3,line=1.2,cex=1,font=1, adj = 0)
  axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
  #mtext("Year", side = 1, line = 4, cex = 1.8, font = 2)
  axis(2, pos = 1.2, seq(0,2.5,by=0.5), las=1)
  par(las = 0)
  mtext("Diversity (H')", side = 2, line = 1.5, cex = 1, font = 1)
  x <- c(1.5, 2.5, 3.5)

  plot.errbars <- plotsegraph(x, c(H_m.15.rf, H_m.16.rf, H_m.17.rf), 
                              c(H_se.15.rf, H_se.16.rf, H_se.17.rf), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.12, c(H_m.15.cn, H_m.16.cn, H_m.17.cn), 
                              c(H_se.15.cn, H_se.16.cn, H_se.17.cn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.06, c(H_m.15.cw, H_m.16.cw, H_m.17.cw), 
                              c(H_se.15.cw, H_se.16.cw, H_se.17.cw), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.12, c(H_m.15.fn, H_m.16.fn, H_m.17.fn), 
                              c(H_se.15.fn, H_se.16.fn, H_se.17.fn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.06, c(H_m.15.fw, H_m.16.fw, H_m.17.fw), 
                              c(H_se.15.fw, H_se.16.fw, H_se.17.fw), 0.07, color = "black")  #0.07 = wiskwidth
  
  lines(x,      c(H_m.15.rf, H_m.16.rf, H_m.17.rf), lwd = 1, type = "c", lty=1,col=colors()[c(320)])
  lines(x+0.12, c(H_m.15.cn, H_m.16.cn, H_m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
  lines(x+0.06, c(H_m.15.cw, H_m.16.cw, H_m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
  lines(x-0.12, c(H_m.15.fn, H_m.16.fn, H_m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
  lines(x-0.06, c(H_m.15.fw, H_m.16.fw, H_m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")

  points(x,      c(H_m.15.rf, H_m.16.rf, H_m.17.rf), cex = 1.8, lwd = 1, pch = 10)
  points(x+0.12, c(H_m.15.cn, H_m.16.cn, H_m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg = "white")
  points(x+0.06, c(H_m.15.cw, H_m.16.cw, H_m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
  points(x-0.12, c(H_m.15.fn, H_m.16.fn, H_m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg = "white")
  points(x-0.06, c(H_m.15.fw, H_m.16.fw, H_m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")
  
#Evenness
  
  plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
       ylim = c(0.5, 0.8), xlim = c(1, 4), lwd = 1, pch = 5, axes = F, main = "")  
  mtext("(d)",side = 3,line=1.2,cex=1,font=1, adj = 0)
  axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
  #mtext("Year", side = 1, line = 4, cex = 1.8, font = 2)
  axis(2, pos = 1.2, seq(0.5,0.8,by=0.05), las=1)
  par(las = 0)
  mtext("Evenness (J')", side = 2, line = 1.5, cex = 1, font = 1)
  x <- c(1.5, 2.5, 3.5)
  
  plot.errbars <- plotsegraph(x, c(J_m.15.rf, J_m.16.rf, J_m.17.rf), 
                              c(J_se.15.rf, J_se.16.rf, J_se.17.rf), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.12, c(J_m.15.cn, J_m.16.cn, J_m.17.cn), 
                              c(J_se.15.cn, J_se.16.cn, J_se.17.cn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.06, c(J_m.15.cw, J_m.16.cw, J_m.17.cw), 
                              c(J_se.15.cw, J_se.16.cw, J_se.17.cw), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.12, c(J_m.15.fn, J_m.16.fn, J_m.17.fn), 
                              c(J_se.15.fn, J_se.16.fn, J_se.17.fn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.06, c(J_m.15.fw, J_m.16.fw, J_m.17.fw), 
                              c(J_se.15.fw, J_se.16.fw, J_se.17.fw), 0.07, color = "black")  #0.07 = wiskwidth
  
  lines(x,      c(J_m.15.rf, J_m.16.rf, J_m.17.rf), lwd = 1, type = "c", lty=1, col=colors()[c(320)])
  lines(x+0.12, c(J_m.15.cn, J_m.16.cn, J_m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
  lines(x+0.06, c(J_m.15.cw, J_m.16.cw, J_m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
  lines(x-0.12, c(J_m.15.fn, J_m.16.fn, J_m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
  lines(x-0.06, c(J_m.15.fw, J_m.16.fw, J_m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")
  
  points(x,      c(J_m.15.rf, J_m.16.rf, J_m.17.rf), cex = 1.8, lwd = 1, pch = 10)
  points(x+0.12, c(J_m.15.cn, J_m.16.cn, J_m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg = "white")
  points(x+0.06, c(J_m.15.cw, J_m.16.cw, J_m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
  points(x-0.12, c(J_m.15.fn, J_m.16.fn, J_m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg = "white")
  points(x-0.06, c(J_m.15.fw, J_m.16.fw, J_m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")
  
  par(mar=c(5,5,0,1)+0.1)
  plot(1,type="n",axes = F,xlab="",ylab="")
  LEGEND("topleft",pch=c(24,17,10), lty=c(1,2,1), col=c("royalblue3","royalblue3",colors()[(320)]),pt.bg="white",pt.col=c("royalblue3","royalblue3",1),pt.cex=2,lwd=1,seg.len=4,bty = "n", cex=1.3, ncol=1,
         pt.lwd=1,y.intersp=1.3,x.intersp=1,legend = c("Cut-stump w/out mulch","Cut-stump w/ mulch", "Reference"))
  plot(1,type="n",axes = F,xlab="",ylab="")
  LEGEND("topleft",pch=c(23,18), lty=c(2,1), col="darkorange",pt.bg="white",pt.col="darkorange",pt.cex=2,lwd=1,seg.len=4,bty = "n", cex=1.3, ncol=1,
         pt.lwd=1,y.intersp=1.3,x.intersp=1,legend = c("MH w/out mulch","MH w/ mulch"))
dev.off()

  
####
  ##Garlic Mustard
  par(mfrow=c(1,1))
    herb.all$Year.rel = herb.all$Year-2015
  
  attach(herb.all)
  
  boxplot(Allipet.h~Treatment+Year)
  
 lm.gm<- lmer(Allipet.h~Treatment*Year.rel+(Year|Site:Plot)+(1|Site))
    plot(lm.gm)
    hist(residuals(lm.gm))
    
    lm.gm.log<-lmer(log(Allipet.h+1)~Treatment*Year.rel+(Year|Site:Plot)+(1|Site))
      plot(lm.gm.log)
      hist(residuals(lm.gm.log),breaks=25)

gm.1516<-herb.16$Allipet.h-herb.15$Allipet.h
  log.gm1516<-ifelse(gm.1516>0,log(gm.1516+1), -log(-gm.1516+1))
gm.1517<-herb.17$Allipet.h-herb.15$Allipet.h
  log.gm1517<-ifelse(gm.1517>0,log(gm.1517+1), -log(-gm.1517+1))

lm.gm1516<-lmer(gm.1516~herb.15$Treatment+(1|herb.15$Site))
  plot(lm.gm1516)
  
  lm.gm1516.log<-lmer(log.gm1516~herb.15$Treatment+(1|herb.15$Site))
    plot(lm.gm1516.log)
    hist(residuals(lm.gm1516.log))
    summary(lm.gm1516.log)
    
    contrast.matrix3<- rbind("Ref vs. 0"=c(1,0,0,0,0),
                             "Ref vs. Cut-"=c(0, 1, 0, 0, 0),
                             "Ref vs. Fecon+"=c(0, 0, 0, 0, 1),
                             "Cut vs Fecon" = c(0, -0.5, -0.5, 0.5, 0.5),
                             "Unmulched vs Mulched" = c(0, -0.5, 0.5, -0.5, 0.5),
                             "Cut- vs Fecon+" = c(0, -1, 0, 0, 1))
    
    summary(glht(lm.gm1516.log, contrast.matrix3))
    
 lm.gm1517<-lmer(gm.1517~herb.15$Treatment+(1|herb.15$Site))
    plot(lm.gm1517)
    
  lm.gm1517.log<-lmer(log.gm1517~herb.15$Treatment+(1|herb.15$Site))
    plot(lm.gm1517.log)
    hist(residuals(lm.gm1517.log), breaks = 20)
    summary(lm.gm1517.log)
    
    summary(glht(lm.gm1517.log, contrast.matrix3))
    
describeBy(herb.15$Allipet.h)    
describeBy(herb.16$Allipet.h, herb.16$Treatment)
describeBy(herb.17$Allipet.h, herb.17$Treatment)



### density of fruiting garlic mustard, 2017
gm.fruit<-read.table("Garlic Mustard Fruiting Counts 2017.csv", sep=',',header=T)
  head(gm.fruit)
    trt.assign<-read.table("Treatment Assignments.csv", sep=',', header=T)

gm.Fruit<-merge(gm.fruit,trt.assign, by="Plot")
gm.Fruit$Treatment<-factor(gm.Fruit$Treatment, levels(gm.Fruit$Treatment)[c(5,1,2,3,4)])
levels(gm.Fruit$Treatment) #ref should be first

attach(gm.Fruit)


lm.gm.f<-lmer(AllipetSeed.per.m2~Treatment+(1|Site))
  plot(lm.gm.f)
  
  lm.gm.f.log<-lmer(log(AllipetSeed.per.m2+1)~Treatment+(1|Site))
    plot(lm.gm.f.log)
    hist(residuals(lm.gm.f.log))
    
    glm.gm<-glmer(AllipetSeed~Treatment+(1|Site),family=poisson)
      plot(glm.gm)
      summary(glht(glm.gm,contrast.matrix3))
      
describeBy(AllipetSeed.per.m2, group=Treatment)     
  gm.counts<-as.matrix(cbind(describeBy(AllipetSeed.per.m2, group=Treatment)$Ref["mean"],
               describeBy(AllipetSeed.per.m2, group=Treatment)$`Cut-`["mean"],
               describeBy(AllipetSeed.per.m2, group=Treatment)$`Cut+`["mean"],
               describeBy(AllipetSeed.per.m2, group=Treatment)$`Fecon-`["mean"],
               describeBy(AllipetSeed.per.m2, group=Treatment)$`Fecon+`["mean"]))
  gm.counts.se<-as.matrix(cbind(describeBy(AllipetSeed.per.m2, group=Treatment)$Ref["se"],
                             describeBy(AllipetSeed.per.m2, group=Treatment)$`Cut-`["se"],
                             describeBy(AllipetSeed.per.m2, group=Treatment)$`Cut+`["se"],
                             describeBy(AllipetSeed.per.m2, group=Treatment)$`Fecon-`["se"],
                             describeBy(AllipetSeed.per.m2, group=Treatment)$`Fecon+`["se"]))
par(mfrow=c(1,1))
library(plyr)
par(bg=NA)
  gm.bplot<-barplot(height=as.vector(t(gm.counts)),ylim=c(0,1.4), axes=T, axisnames=F, col=colors()[c(296,592,593,54,55)])
    l_ply(seq_along(gm.bplot), function(x) arrows(x0 = gm.bplot[x], y0=as.matrix(gm.counts)[x],x1=gm.bplot[x],
                                                     y1=as.matrix(gm.counts)[x]+as.matrix(gm.counts.se)[x], code=2,length=0.1,angle=90,lwd=1.5))
    mtext(side=2, line=3.5, las=0,expression("Garlic mustard seed heads (per m"^"2"*")"),cex=1.8)
    axis(side=1, at=c(0.7,1.9,3.1,4.3,5.5), labels=c("","no mulch","w/ mulch","no mulch","w/ mulch"), cex.lab=1.3)
    mtext(side=1, line=3, at=c(0.7,2.5,4.9), text=c("Ref","Cut-stump","Fecon"),cex=2)
detach(gm.Fruit)
      