##################################
# Honeysuckle seedling densities #

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")
HS.counts<-read.table("Honeysuckle Cover and Seedling Counts.csv", header=T, sep=',', nrows=288)
  
  # "sm" indicates  seedlings <0.5 m tall
  # "lg" indicates seedlings 0.5 - 1.37 m tall

library(lme4)
library(lmerTest)
library(multcomp)
library(psych)

  head(HS.counts)
  nrow(HS.counts)

HS.counts$Treatment<-factor(HS.counts$Treatment,levels(HS.counts$Treatment)[c(5,1,2,3,4)])
HS.counts$Removal<-factor(HS.counts$Removal, levels(HS.counts$Removal)[c(3,1,2)])
HS.counts$Mulch<-factor(HS.counts$Mulch, levels(HS.counts$Mulch)[c(2,3,1)])

HS.counts$sm.HS.dens<-HS.counts$small_ct*25 #density per 100m^2
HS.counts$lg.HS.dens<-HS.counts$large_ct*25
HS.counts$all.HS.dens<-HS.counts$all_ct*25

contrast.matrix <- rbind("Year:Ref vs. 0" = c(0, 1, 0, 0, 0, 0, 0, 0, 0, 0),
                         "Year:Ref vs. Year:Cut-" =  c(0, 0, 0, 0, 0, 0, 1, 0, 0, 0),
                         "Year:Ref vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1),
                         "Year:Unmulched vs Year:Mulched"=c(0,0,0,0,0,0,-0.5,0.5,-0.5,0.5),
                         "Year:Cut vs Year:Fecon"=c(0,0,0,0,0,0,-0.5,-0.5,0.5,0.5),
                         "Year:Cut- vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, -1, 0, 0, 1))

HS.counts$year = HS.counts$Year - 2015 #year of the experiment

attach(HS.counts)

hist(small_ct, breaks=25)
hist(large_ct)


############################################################
### Use Linear Mixed Models of Density per 100m^2 for now #
lm.sm.dens<-lmer(sm.HS.dens~Treatment*year+(year|Site:Plot)+(1|Site))
  plot(lm.sm.dens)
  
  lm.sm.dens.log<-lmer(log(sm.HS.dens+1)~Treatment*year+(year|Site:Plot)+(1|Site))
    plot(lm.sm.dens.log)
    hist(residuals(lm.sm.dens.log))
    
    anova(lm.sm.dens.log)
    

lm.lg.dens<-lmer(lg.HS.dens~Treatment*year+(year|Site:Plot)+(1|Site))
    plot(lm.lg.dens)
    hist(residuals(lm.lg.dens))
    
    lm.lg.dens.log<-lmer(log(lg.HS.dens+1)~Treatment*year+(year|Site:Plot)+(1|Site))
      plot(lm.lg.dens.log)
      hist(residuals(lm.lg.dens.log)) #too much
    
    summary(lm.lg.dens)
    anova(lm.lg.dens)
    summary(glht(lm.lg.dens, contrast.matrix))

    
boxplot(large_ct~Treatment+year)
####### summary statistics and figures ##########  
HS.counts.15<-subset(HS.counts, HS.counts$year=="0")
HS.counts.16<-subset(HS.counts, HS.counts$year=="1")
HS.counts.17<-subset(HS.counts, HS.counts$year=="2")

describeBy(HS.counts.15,group=HS.counts.15$Treatment)
  describeBy(HS.counts.16$sm.HS.dens-HS.counts.15$sm.HS.dens,group=HS.counts.15$Treatment)
  (1660.94-1987.5)/1987.5 #proportional effect of mulch in cut-stump
  (5542.19-6095.31)/6095.31 #proportional effect of mulch in Fecon
  
describeBy(HS.counts.16,group="Treatment")
describeBy(HS.counts.17,group="Treatment")

# Error Bar Function
plotsegraph <- function(loc, value, sterr, wiskwidth, color = "grey", linewidth = 1) {
  
  w <- wiskwidth/2
  segments(x0 = loc, x1 = loc, y0 = value - sterr, y1 = value + sterr, col = color, 
           lwd = linewidth)
  segments(x0 = loc - w, x1 = loc + w, y0 = value + sterr, y1 = value + sterr, 
           col = color, lwd = linewidth)  # upper whiskers
  segments(x0 = loc - w, x1 = loc + w, y0 = value - sterr, y1 = value - sterr, 
           col = color, lwd = linewidth)  # lower whiskers
}
#Table of means
HS.sm.means <- data.frame(matrix(vector(), 5, 3,
                                 dimnames=list(c(), c("2015", "2016", "2017"))),
                          stringsAsFactors=F)
rownames(HS.sm.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
HS.sm.means[,1]<-c(describeBy(HS.counts.15,group="Treatment")$`Ref`["sm.HS.dens","mean"],
                   describeBy(HS.counts.15,group="Treatment")$`Cut-`["sm.HS.dens","mean"],
                   describeBy(HS.counts.15,group="Treatment")$`Cut+`["sm.HS.dens","mean"],
                   describeBy(HS.counts.15,group="Treatment")$`Fecon-`["sm.HS.dens","mean"],
                   describeBy(HS.counts.15,group="Treatment")$`Fecon+`["sm.HS.dens","mean"])
HS.sm.means[,2]<-c(describeBy(HS.counts.16,group="Treatment")$`Ref`["sm.HS.dens","mean"],
                   describeBy(HS.counts.16,group="Treatment")$`Cut-`["sm.HS.dens","mean"],
                   describeBy(HS.counts.16,group="Treatment")$`Cut+`["sm.HS.dens","mean"],
                   describeBy(HS.counts.16,group="Treatment")$`Fecon-`["sm.HS.dens","mean"],
                   describeBy(HS.counts.16,group="Treatment")$`Fecon+`["sm.HS.dens","mean"])
HS.sm.means[,3]<-c(describeBy(HS.counts.17,group="Treatment")$`Ref`["sm.HS.dens","mean"],
                   describeBy(HS.counts.17,group="Treatment")$`Cut-`["sm.HS.dens","mean"],
                   describeBy(HS.counts.17,group="Treatment")$`Cut+`["sm.HS.dens","mean"],
                   describeBy(HS.counts.17,group="Treatment")$`Fecon-`["sm.HS.dens","mean"],
                   describeBy(HS.counts.17,group="Treatment")$`Fecon+`["sm.HS.dens","mean"])

## generate SE table
se.HS.sm.means <- data.frame(matrix(vector(), 5, 3,
                                    dimnames=list(c(), c("2015", "2016", "2017"))),
                             stringsAsFactors=F)
rownames(se.HS.sm.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
se.HS.sm.means[,1]<-c(describeBy(HS.counts.15,group="Treatment")$`Ref`["sm.HS.dens","se"],
                      describeBy(HS.counts.15,group="Treatment")$`Cut-`["sm.HS.dens","se"],
                      describeBy(HS.counts.15,group="Treatment")$`Cut+`["sm.HS.dens","se"],
                      describeBy(HS.counts.15,group="Treatment")$`Fecon-`["sm.HS.dens","se"],
                      describeBy(HS.counts.15,group="Treatment")$`Fecon+`["sm.HS.dens","se"])
se.HS.sm.means[,2]<-c(describeBy(HS.counts.16,group="Treatment")$`Ref`["sm.HS.dens","se"],
                      describeBy(HS.counts.16,group="Treatment")$`Cut-`["sm.HS.dens","se"],
                      describeBy(HS.counts.16,group="Treatment")$`Cut+`["sm.HS.dens","se"],
                      describeBy(HS.counts.16,group="Treatment")$`Fecon-`["sm.HS.dens","se"],
                      describeBy(HS.counts.16,group="Treatment")$`Fecon+`["sm.HS.dens","se"])
se.HS.sm.means[,3]<-c(describeBy(HS.counts.17,group="Treatment")$`Ref`["sm.HS.dens","se"],
                      describeBy(HS.counts.17,group="Treatment")$`Cut-`["sm.HS.dens","se"],
                      describeBy(HS.counts.17,group="Treatment")$`Cut+`["sm.HS.dens","se"],
                      describeBy(HS.counts.17,group="Treatment")$`Fecon-`["sm.HS.dens","se"],
                      describeBy(HS.counts.17,group="Treatment")$`Fecon+`["sm.HS.dens","se"])

sm_m.15.rf<-HS.sm.means[1,1]
sm_m.15.cn<-HS.sm.means[2,1]
sm_m.15.cw<-HS.sm.means[3,1]
sm_m.15.fn<-HS.sm.means[4,1]
sm_m.15.fw<-HS.sm.means[5,1]
sm_m.16.rf<-HS.sm.means[1,2]
sm_m.16.cn<-HS.sm.means[2,2]
sm_m.16.cw<-HS.sm.means[3,2]
sm_m.16.fn<-HS.sm.means[4,2]
sm_m.16.fw<-HS.sm.means[5,2]
sm_m.17.rf<-HS.sm.means[1,3]
sm_m.17.cn<-HS.sm.means[2,3]
sm_m.17.cw<-HS.sm.means[3,3]
sm_m.17.fn<-HS.sm.means[4,3]
sm_m.17.fw<-HS.sm.means[5,3]

sm_se.15.rf<-se.HS.sm.means[1,1]
sm_se.15.cn<-se.HS.sm.means[2,1]
sm_se.15.cw<-se.HS.sm.means[3,1]
sm_se.15.fn<-se.HS.sm.means[4,1]
sm_se.15.fw<-se.HS.sm.means[5,1]
sm_se.16.rf<-se.HS.sm.means[1,2]
sm_se.16.cn<-se.HS.sm.means[2,2]
sm_se.16.cw<-se.HS.sm.means[3,2]
sm_se.16.fn<-se.HS.sm.means[4,2]
sm_se.16.fw<-se.HS.sm.means[5,2]
sm_se.17.rf<-se.HS.sm.means[1,3]
sm_se.17.cn<-se.HS.sm.means[2,3]
sm_se.17.cw<-se.HS.sm.means[3,3]
sm_se.17.fn<-se.HS.sm.means[4,3]
sm_se.17.fw<-se.HS.sm.means[5,3]


#### Generate mean and SE table for large seedlings
#Table of means
HS.lg.means <- data.frame(matrix(vector(), 5, 3,
                                 dimnames=list(c(), c("2015", "2016", "2017"))),
                          stringsAsFactors=F)
rownames(HS.lg.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
HS.lg.means[,1]<-c(describeBy(HS.counts.15,group="Treatment")$`Ref`["lg.HS.dens","mean"],
                   describeBy(HS.counts.15,group="Treatment")$`Cut-`["lg.HS.dens","mean"],
                   describeBy(HS.counts.15,group="Treatment")$`Cut+`["lg.HS.dens","mean"],
                   describeBy(HS.counts.15,group="Treatment")$`Fecon-`["lg.HS.dens","mean"],
                   describeBy(HS.counts.15,group="Treatment")$`Fecon+`["lg.HS.dens","mean"])
HS.lg.means[,2]<-c(describeBy(HS.counts.16,group="Treatment")$`Ref`["lg.HS.dens","mean"],
                   describeBy(HS.counts.16,group="Treatment")$`Cut-`["lg.HS.dens","mean"],
                   describeBy(HS.counts.16,group="Treatment")$`Cut+`["lg.HS.dens","mean"],
                   describeBy(HS.counts.16,group="Treatment")$`Fecon-`["lg.HS.dens","mean"],
                   describeBy(HS.counts.16,group="Treatment")$`Fecon+`["lg.HS.dens","mean"])
HS.lg.means[,3]<-c(describeBy(HS.counts.17,group="Treatment")$`Ref`["lg.HS.dens","mean"],
                   describeBy(HS.counts.17,group="Treatment")$`Cut-`["lg.HS.dens","mean"],
                   describeBy(HS.counts.17,group="Treatment")$`Cut+`["lg.HS.dens","mean"],
                   describeBy(HS.counts.17,group="Treatment")$`Fecon-`["lg.HS.dens","mean"],
                   describeBy(HS.counts.17,group="Treatment")$`Fecon+`["lg.HS.dens","mean"])

## generate SE table
se.HS.lg.means <- data.frame(matrix(vector(), 5, 3,
                                    dimnames=list(c(), c("2015", "2016", "2017"))),
                             stringsAsFactors=F)
rownames(se.HS.lg.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
se.HS.lg.means[,1]<-c(describeBy(HS.counts.15,group="Treatment")$`Ref`["lg.HS.dens","se"],
                      describeBy(HS.counts.15,group="Treatment")$`Cut-`["lg.HS.dens","se"],
                      describeBy(HS.counts.15,group="Treatment")$`Cut+`["lg.HS.dens","se"],
                      describeBy(HS.counts.15,group="Treatment")$`Fecon-`["lg.HS.dens","se"],
                      describeBy(HS.counts.15,group="Treatment")$`Fecon+`["lg.HS.dens","se"])
se.HS.lg.means[,2]<-c(describeBy(HS.counts.16,group="Treatment")$`Ref`["lg.HS.dens","se"],
                      describeBy(HS.counts.16,group="Treatment")$`Cut-`["lg.HS.dens","se"],
                      describeBy(HS.counts.16,group="Treatment")$`Cut+`["lg.HS.dens","se"],
                      describeBy(HS.counts.16,group="Treatment")$`Fecon-`["lg.HS.dens","se"],
                      describeBy(HS.counts.16,group="Treatment")$`Fecon+`["lg.HS.dens","se"])
se.HS.lg.means[,3]<-c(describeBy(HS.counts.17,group="Treatment")$`Ref`["lg.HS.dens","se"],
                      describeBy(HS.counts.17,group="Treatment")$`Cut-`["lg.HS.dens","se"],
                      describeBy(HS.counts.17,group="Treatment")$`Cut+`["lg.HS.dens","se"],
                      describeBy(HS.counts.17,group="Treatment")$`Fecon-`["lg.HS.dens","se"],
                      describeBy(HS.counts.17,group="Treatment")$`Fecon+`["lg.HS.dens","se"])

lg_m.15.rf<-HS.lg.means[1,1]
lg_m.15.cn<-HS.lg.means[2,1]
lg_m.15.cw<-HS.lg.means[3,1]
lg_m.15.fn<-HS.lg.means[4,1]
lg_m.15.fw<-HS.lg.means[5,1]
lg_m.16.rf<-HS.lg.means[1,2]
lg_m.16.cn<-HS.lg.means[2,2]
lg_m.16.cw<-HS.lg.means[3,2]
lg_m.16.fn<-HS.lg.means[4,2]
lg_m.16.fw<-HS.lg.means[5,2]
lg_m.17.rf<-HS.lg.means[1,3]
lg_m.17.cn<-HS.lg.means[2,3]
lg_m.17.cw<-HS.lg.means[3,3]
lg_m.17.fn<-HS.lg.means[4,3]
lg_m.17.fw<-HS.lg.means[5,3]

lg_se.15.rf<-se.HS.lg.means[1,1]
lg_se.15.cn<-se.HS.lg.means[2,1]
lg_se.15.cw<-se.HS.lg.means[3,1]
lg_se.15.fn<-se.HS.lg.means[4,1]
lg_se.15.fw<-se.HS.lg.means[5,1]
lg_se.16.rf<-se.HS.lg.means[1,2]
lg_se.16.cn<-se.HS.lg.means[2,2]
lg_se.16.cw<-se.HS.lg.means[3,2]
lg_se.16.fn<-se.HS.lg.means[4,2]
lg_se.16.fw<-se.HS.lg.means[5,2]
lg_se.17.rf<-se.HS.lg.means[1,3]
lg_se.17.cn<-se.HS.lg.means[2,3]
lg_se.17.cw<-se.HS.lg.means[3,3]
lg_se.17.fn<-se.HS.lg.means[4,3]
lg_se.17.fw<-se.HS.lg.means[5,3]


detach(HS.counts)

#load in cover data for composite figure

HS.cover<-read.table("Honeysuckle Cover and Seedling Counts.csv", sep=',', header=T)
  HS.und.15<-subset(HS.cover, HS.cover$Year=="2015")
  HS.und.16<-subset(HS.cover, HS.cover$Year=="2016")
  HS.und.17<-subset(HS.cover, HS.cover$Year=="2017")
  
  # means for cover
  hs.und.means <- data.frame(matrix(vector(), 5, 3,
                                    dimnames=list(c(), c("2015", "2016", "2017"))),
                             stringsAsFactors=F)
  rownames(hs.und.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
  hs.und.means[,1]<-c(describeBy(HS.und.15,group="Treatment")$`Ref`["HerbLayerCover","mean"],
                      describeBy(HS.und.15,group="Treatment")$`Cut-`["HerbLayerCover","mean"],
                      describeBy(HS.und.15,group="Treatment")$`Cut+`["HerbLayerCover","mean"],
                      describeBy(HS.und.15,group="Treatment")$`Fecon-`["HerbLayerCover","mean"],
                      describeBy(HS.und.15,group="Treatment")$`Fecon+`["HerbLayerCover","mean"])
  hs.und.means[,2]<-c(describeBy(HS.und.16,group="Treatment")$`Ref`["HerbLayerCover","mean"],
                      describeBy(HS.und.16,group="Treatment")$`Cut-`["HerbLayerCover","mean"],
                      describeBy(HS.und.16,group="Treatment")$`Cut+`["HerbLayerCover","mean"],
                      describeBy(HS.und.16,group="Treatment")$`Fecon-`["HerbLayerCover","mean"],
                      describeBy(HS.und.16,group="Treatment")$`Fecon+`["HerbLayerCover","mean"])
  hs.und.means[,3]<-c(describeBy(HS.und.17,group="Treatment")$`Ref`["HerbLayerCover","mean"],
                      describeBy(HS.und.17,group="Treatment")$`Cut-`["HerbLayerCover","mean"],
                      describeBy(HS.und.17,group="Treatment")$`Cut+`["HerbLayerCover","mean"],
                      describeBy(HS.und.17,group="Treatment")$`Fecon-`["HerbLayerCover","mean"],
                      describeBy(HS.und.17,group="Treatment")$`Fecon+`["HerbLayerCover","mean"])
  
  cov_m.15.rf<-hs.und.means[1,1]
  cov_m.15.cn<-hs.und.means[2,1]
  cov_m.15.cw<-hs.und.means[3,1]
  cov_m.15.fn<-hs.und.means[4,1]
  cov_m.15.fw<-hs.und.means[5,1]
  cov_m.16.rf<-hs.und.means[1,2]
  cov_m.16.cn<-hs.und.means[2,2]
  cov_m.16.cw<-hs.und.means[3,2]
  cov_m.16.fn<-hs.und.means[4,2]
  cov_m.16.fw<-hs.und.means[5,2]
  cov_m.17.rf<-hs.und.means[1,3]
  cov_m.17.cn<-hs.und.means[2,3]
  cov_m.17.cw<-hs.und.means[3,3]
  cov_m.17.fn<-hs.und.means[4,3]
  cov_m.17.fw<-hs.und.means[5,3]
  
#SEs of cover
  hs.und.se <- data.frame(matrix(vector(), 5, 3,
                                    dimnames=list(c(), c("2015", "2016", "2017"))),
                             stringsAsFactors=F)
  rownames(hs.und.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
  hs.und.se[,1]<-c(describeBy(HS.und.15,group="Treatment")$`Ref`["HerbLayerCover","se"],
                      describeBy(HS.und.15,group="Treatment")$`Cut-`["HerbLayerCover","se"],
                      describeBy(HS.und.15,group="Treatment")$`Cut+`["HerbLayerCover","se"],
                      describeBy(HS.und.15,group="Treatment")$`Fecon-`["HerbLayerCover","se"],
                      describeBy(HS.und.15,group="Treatment")$`Fecon+`["HerbLayerCover","se"])
  hs.und.se[,2]<-c(describeBy(HS.und.16,group="Treatment")$`Ref`["HerbLayerCover","se"],
                      describeBy(HS.und.16,group="Treatment")$`Cut-`["HerbLayerCover","se"],
                      describeBy(HS.und.16,group="Treatment")$`Cut+`["HerbLayerCover","se"],
                      describeBy(HS.und.16,group="Treatment")$`Fecon-`["HerbLayerCover","se"],
                      describeBy(HS.und.16,group="Treatment")$`Fecon+`["HerbLayerCover","se"])
  hs.und.se[,3]<-c(describeBy(HS.und.17,group="Treatment")$`Ref`["HerbLayerCover","se"],
                      describeBy(HS.und.17,group="Treatment")$`Cut-`["HerbLayerCover","se"],
                      describeBy(HS.und.17,group="Treatment")$`Cut+`["HerbLayerCover","se"],
                      describeBy(HS.und.17,group="Treatment")$`Fecon-`["HerbLayerCover","se"],
                      describeBy(HS.und.17,group="Treatment")$`Fecon+`["HerbLayerCover","se"])
  
  cov_se.15.rf<-hs.und.se[1,1]
  cov_se.15.cn<-hs.und.se[2,1]
  cov_se.15.cw<-hs.und.se[3,1]
  cov_se.15.fn<-hs.und.se[4,1]
  cov_se.15.fw<-hs.und.se[5,1]
  cov_se.16.rf<-hs.und.se[1,2]
  cov_se.16.cn<-hs.und.se[2,2]
  cov_se.16.cw<-hs.und.se[3,2]
  cov_se.16.fn<-hs.und.se[4,2]
  cov_se.16.fw<-hs.und.se[5,2]
  cov_se.17.rf<-hs.und.se[1,3]
  cov_se.17.cn<-hs.und.se[2,3]
  cov_se.17.cw<-hs.und.se[3,3]
  cov_se.17.fn<-hs.und.se[4,3]
  cov_se.17.fw<-hs.und.se[5,3]

### Figures for Manuscript ###
  
  #Legend function modification
  LEGEND <- function (x, y = NULL, legend, fill = NULL, 
                      col = par("col"), pt.col=col, line.col=col,
                      border = "black", lty, lwd, pch, angle = 45, density = NULL,
                      bty = "o", bg = par("bg"), box.lwd = par("lwd"), box.lty = par("lty"),
                      box.col = par("fg"), pt.bg = NA, cex = 1, pt.cex = cex, pt.lwd = lwd,
                      xjust = 0, yjust = 1, x.intersp = 1, y.intersp = 1, adj = c(0,
                                                                                  0.5), text.width = NULL, text.col = par("col"), text.font = NULL,
                      merge = do.lines && has.pch, trace = FALSE, plot = TRUE,
                      ncol = 1, horiz = FALSE, title = NULL, inset = 0, xpd, title.col = text.col,
                      title.adj = 0.5, seg.len = 2)
  {
    if (missing(legend) && !missing(y) && (is.character(y) ||
                                           is.expression(y))) {
      legend <- y
      y <- NULL
    }
    mfill <- !missing(fill) || !missing(density)
    if (!missing(xpd)) {
      op <- par("xpd")
      on.exit(par(xpd = op))
      par(xpd = xpd)
    }
    title <- as.graphicsAnnot(title)
    if (length(title) > 1)
      stop("invalid 'title'")
    legend <- as.graphicsAnnot(legend)
    n.leg <- if (is.call(legend))
      1
    else length(legend)
    if (n.leg == 0)
      stop("'legend' is of length 0")
    auto <- if (is.character(x))
      match.arg(x, c("bottomright", "bottom", "bottomleft",
                     "left", "topleft", "top", "topright", "right", "center"))
    else NA
    if (is.na(auto)) {
      xy <- xy.coords(x, y)
      x <- xy$x
      y <- xy$y
      nx <- length(x)
      if (nx < 1 || nx > 2)
        stop("invalid coordinate lengths")
    }
    else nx <- 0
    xlog <- par("xlog")
    ylog <- par("ylog")
    rect2 <- function(left, top, dx, dy, density = NULL, angle,
                      ...) {
      r <- left + dx
      if (xlog) {
        left <- 10^left
        r <- 10^r
      }
      b <- top - dy
      if (ylog) {
        top <- 10^top
        b <- 10^b
      }
      rect(left, top, r, b, angle = angle, density = density,
           ...)
    }
    segments2 <- function(x1, y1, dx, dy, ...) {
      x2 <- x1 + dx
      if (xlog) {
        x1 <- 10^x1
        x2 <- 10^x2
      }
      y2 <- y1 + dy
      if (ylog) {
        y1 <- 10^y1
        y2 <- 10^y2
      }
      segments(x1, y1, x2, y2, ...)
    }
    points2 <- function(x, y, ...) {
      if (xlog)
        x <- 10^x
      if (ylog)
        y <- 10^y
      points(x, y, ...)
    }
    text2 <- function(x, y, ...) {
      if (xlog)
        x <- 10^x
      if (ylog)
        y <- 10^y
      text(x, y, ...)
    }
    if (trace)
      catn <- function(...) do.call("cat", c(lapply(list(...),
                                                    formatC), list("\n")))
    cin <- par("cin")
    Cex <- cex * par("cex")
    if (is.null(text.width))
      text.width <- max(abs(strwidth(legend, units = "user",
                                     cex = cex, font = text.font)))
    else if (!is.numeric(text.width) || text.width < 0)
      stop("'text.width' must be numeric, >= 0")
    xc <- Cex * xinch(cin[1L], warn.log = FALSE)
    yc <- Cex * yinch(cin[2L], warn.log = FALSE)
    if (xc < 0)
      text.width <- -text.width
    xchar <- xc
    xextra <- 0
    yextra <- yc * (y.intersp - 1)
    ymax <- yc * max(1, strheight(legend, units = "user", cex = cex)/yc)
    ychar <- yextra + ymax
    if (trace)
      catn("  xchar=", xchar, "; (yextra,ychar)=", c(yextra,
                                                     ychar))
    if (mfill) {
      xbox <- xc * 0.8
      ybox <- yc * 0.5
      dx.fill <- xbox
    }
    do.lines <- (!missing(lty) && (is.character(lty) || any(lty >
                                                              0))) || !missing(lwd)
    n.legpercol <- if (horiz) {
      if (ncol != 1)
        warning(gettextf("horizontal specification overrides: Number of columns := %d",
                         n.leg), domain = NA)
      ncol <- n.leg
      1
    }
    else ceiling(n.leg/ncol)
    has.pch <- !missing(pch) && length(pch) > 0
    if (do.lines) {
      x.off <- if (merge)
        -0.7
      else 0
    }
    else if (merge)
      warning("'merge = TRUE' has no effect when no line segments are drawn")
    if (has.pch) {
      if (is.character(pch) && !is.na(pch[1L]) && nchar(pch[1L],
                                                        type = "c") > 1) {
        if (length(pch) > 1)
          warning("not using pch[2..] since pch[1L] has multiple chars")
        np <- nchar(pch[1L], type = "c")
        pch <- substr(rep.int(pch[1L], np), 1L:np, 1L:np)
      }
      if (!is.character(pch))
        pch <- as.integer(pch)
    }
    if (is.na(auto)) {
      if (xlog)
        x <- log10(x)
      if (ylog)
        y <- log10(y)
    }
    if (nx == 2) {
      x <- sort(x)
      y <- sort(y)
      left <- x[1L]
      top <- y[2L]
      w <- diff(x)
      h <- diff(y)
      w0 <- w/ncol
      x <- mean(x)
      y <- mean(y)
      if (missing(xjust))
        xjust <- 0.5
      if (missing(yjust))
        yjust <- 0.5
    }
    else {
      h <- (n.legpercol + (!is.null(title))) * ychar + yc
      w0 <- text.width + (x.intersp + 1) * xchar
      if (mfill)
        w0 <- w0 + dx.fill
      if (do.lines)
        w0 <- w0 + (seg.len + x.off) * xchar
      w <- ncol * w0 + 0.5 * xchar
      if (!is.null(title) && (abs(tw <- strwidth(title, units = "user",
                                                 cex = cex) + 0.5 * xchar)) > abs(w)) {
        xextra <- (tw - w)/2
        w <- tw
      }
      if (is.na(auto)) {
        left <- x - xjust * w
        top <- y + (1 - yjust) * h
      }
      else {
        usr <- par("usr")
        inset <- rep_len(inset, 2)
        insetx <- inset[1L] * (usr[2L] - usr[1L])
        left <- switch(auto, bottomright = , topright = ,
                       right = usr[2L] - w - insetx, bottomleft = ,
                       left = , topleft = usr[1L] + insetx, bottom = ,
                       top = , center = (usr[1L] + usr[2L] - w)/2)
        insety <- inset[2L] * (usr[4L] - usr[3L])
        top <- switch(auto, bottomright = , bottom = , bottomleft = usr[3L] +
                        h + insety, topleft = , top = , topright = usr[4L] -
                        insety, left = , right = , center = (usr[3L] +
                                                               usr[4L] + h)/2)
      }
    }
    if (plot && bty != "n") {
      if (trace)
        catn("  rect2(", left, ",", top, ", w=", w, ", h=",
             h, ", ...)", sep = "")
      rect2(left, top, dx = w, dy = h, col = bg, density = NULL,
            lwd = box.lwd, lty = box.lty, border = box.col)
    }
    xt <- left + xchar + xextra + (w0 * rep.int(0:(ncol - 1),
                                                rep.int(n.legpercol, ncol)))[1L:n.leg]
    yt <- top - 0.5 * yextra - ymax - (rep.int(1L:n.legpercol,
                                               ncol)[1L:n.leg] - 1 + (!is.null(title))) * ychar
    if (mfill) {
      if (plot) {
        if (!is.null(fill))
          fill <- rep_len(fill, n.leg)
        rect2(left = xt, top = yt + ybox/2, dx = xbox, dy = ybox,
              col = fill, density = density, angle = angle,
              border = border)
      }
      xt <- xt + dx.fill
    }
    if (plot && (has.pch || do.lines)) {
      pt.COL <- rep_len(pt.col, n.leg)
      line.COL <- rep_len(line.col, n.leg)
    }
    if (missing(lwd) || is.null(lwd))
      lwd <- par("lwd")
    if (do.lines) {
      if (missing(lty) || is.null(lty))
        lty <- 1
      lty <- rep_len(lty, n.leg)
      lwd <- rep_len(lwd, n.leg)
      ok.l <- !is.na(lty) & (is.character(lty) | lty > 0) &
        !is.na(lwd)
      if (trace)
        catn("  segments2(", xt[ok.l] + x.off * xchar, ",",
             yt[ok.l], ", dx=", seg.len * xchar, ", dy=0, ...)")
      if (plot)
        segments2(xt[ok.l] + x.off * xchar, yt[ok.l], dx = seg.len *
                    xchar, dy = 0, lty = lty[ok.l], lwd = lwd[ok.l],
                  col = line.COL[ok.l])
      xt <- xt + (seg.len + x.off) * xchar
    }
    if (has.pch) {
      pch <- rep_len(pch, n.leg)
      pt.bg <- rep_len(pt.bg, n.leg)
      pt.cex <- rep_len(pt.cex, n.leg)
      pt.lwd <- rep_len(pt.lwd, n.leg)
      ok <- !is.na(pch)
      if (!is.character(pch)) {
        ok <- ok & (pch >= 0 | pch <= -32)
      }
      else {
        ok <- ok & nzchar(pch)
      }
      x1 <- (if (merge && do.lines)
        xt - (seg.len/2) * xchar
        else xt)[ok]
      y1 <- yt[ok]
      if (trace)
        catn("  points2(", x1, ",", y1, ", pch=", pch[ok],
             ", ...)")
      if (plot)
        points2(x1, y1, pch = pch[ok], col = pt.COL[ok], cex = pt.cex[ok],
                bg = pt.bg[ok], lwd = pt.lwd[ok])
    }
    xt <- xt + x.intersp * xchar
    if (plot) {
      if (!is.null(title))
        text2(left + w * title.adj, top - ymax, labels = title,
              adj = c(title.adj, 0), cex = cex, col = title.col)
      text2(xt, yt, labels = legend, adj = adj, cex = cex,
            col = text.col, font = text.font)
    }
    invisible(list(rect = list(w = w, h = h, left = left, top = top),
                   text = list(x = xt, y = yt)))
  }

  
tiff("Fig. 2_Honeysuckle Seedlings.tiff", compression = "lzw", height= 5.5, width = 7, units = "in", res=400, pointsize = 11)  
#par(mfrow=c(4,1))

m <- matrix(c(1,2,4,3),nrow = 2,ncol = 2,byrow = F)
  
 layout(mat = m, heights = 1, widths = c(1,1,1,1))
  
par(cex.main = 1, mar = c(4,4,3,1) + 0.1, mgp = c(3.5, 1, 0), cex.lab = 1.5, 
    font.lab = 2, cex.axis = 1, bty = "n", las = 1)
par(bg=NA) #transparent background

x1 <- c(1, 2, 3, 4)
y1 <- rep(-1000,4)
#Cover
plot(x1, y1, type = "p", ylab = "", xlab = " ", cex = 1.5, 
     ylim = c(0, 35), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  #Total Seedling Cover
  mtext("a)",side = 3,line=1.5, cex=1, font=1, adj = 0)
  axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
  mtext("Year", side = 1, line = 3, cex = 1, font = 1)
  axis(2, pos = 1.2, seq(0,35,by=5), las=1)
  par(las = 0)
  mtext(expression("Percent Cover"), side = 2, line = 1.5, cex = 1, font = 2)

  x <- c(1.5, 2.5, 3.5)
    
  plot.errbars <- plotsegraph(x, c(cov_m.15.rf, cov_m.16.rf, cov_m.17.rf), 
                              c(cov_se.15.rf, cov_se.16.rf, cov_se.17.rf), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.12, c(cov_m.15.cn, cov_m.16.cn, cov_m.17.cn), 
                              c(cov_se.15.cn, cov_se.16.cn, cov_se.17.cn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.06, c(cov_m.15.cw, cov_m.16.cw, cov_m.17.cw), 
                              c(cov_se.15.cw, cov_se.16.cw, cov_se.17.cw), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.12, c(cov_m.15.fn, cov_m.16.fn, cov_m.17.fn), 
                              c(cov_se.15.fn, cov_se.16.fn, cov_se.17.fn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.06, c(cov_m.15.fw, cov_m.16.fw, cov_m.17.fw), 
                              c(cov_se.15.fw, cov_se.16.fw, cov_se.17.fw), 0.07, color = "black")  #0.07 = wiskwidth
  
  lines(x,      c(cov_m.15.rf, cov_m.16.rf, cov_m.17.rf), lwd = 1, type = "c", lty=1, col=colors()[c(320)])
  lines(x+0.12, c(cov_m.15.cn, cov_m.16.cn, cov_m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
  lines(x+0.06, c(cov_m.15.cw, cov_m.16.cw, cov_m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
  lines(x-0.12, c(cov_m.15.fn, cov_m.16.fn, cov_m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
  lines(x-0.06, c(cov_m.15.fw, cov_m.16.fw, cov_m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")
  
    points(x,      c(cov_m.15.rf, cov_m.16.rf, cov_m.17.rf), cex = 1.8, lwd = 1, pch = 10)
    points(x+0.12, c(cov_m.15.cn, cov_m.16.cn, cov_m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg="white")
    points(x+0.06, c(cov_m.15.cw, cov_m.16.cw, cov_m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
    points(x-0.12, c(cov_m.15.fn, cov_m.16.fn, cov_m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg="white")
    points(x-0.06, c(cov_m.15.fw, cov_m.16.fw, cov_m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")
    

#small seedlings
plot(x1, c(-1000, -1000, -1000, -1000), type = "p", ylab = "", xlab = " ", cex = 1.5, 
     ylim = c(0, 9000), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  #Total Seedling Cover
  mtext("b)",side = 3,line=1.5, cex=1, font=1, adj = 0)
  axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
  mtext("Year", side = 1, line = 3, cex = 1, font = 1)
  axis(2, pos = 1.2, c(0,seq(1000,9000,by=2000)), las=1)
  par(las = 0)
  mtext(expression("Small Seedlings 100 m "^-2), side = 2, line = 1.5, cex = 1, font = 2)

  x <- c(1.5, 2.5, 3.5)
  
  plot.errbars <- plotsegraph(x, c(sm_m.15.rf, sm_m.16.rf, sm_m.17.rf), 
                              c(sm_se.15.rf, sm_se.16.rf, sm_se.17.rf), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.12, c(sm_m.15.cn, sm_m.16.cn, sm_m.17.cn), 
                              c(sm_se.15.cn, sm_se.16.cn, sm_se.17.cn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.06, c(sm_m.15.cw, sm_m.16.cw, sm_m.17.cw), 
                              c(sm_se.15.cw, sm_se.16.cw, sm_se.17.cw), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.12, c(sm_m.15.fn, sm_m.16.fn, sm_m.17.fn), 
                              c(sm_se.15.fn, sm_se.16.fn, sm_se.17.fn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.06, c(sm_m.15.fw, sm_m.16.fw, sm_m.17.fw), 
                              c(sm_se.15.fw, sm_se.16.fw, sm_se.17.fw), 0.07, color = "black")  #0.07 = wiskwidth
  
  lines(x,      c(sm_m.15.rf, sm_m.16.rf, sm_m.17.rf), lwd = 1, type = "c", lty=1, col=colors()[c(320)])
  lines(x+0.12, c(sm_m.15.cn, sm_m.16.cn, sm_m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
  lines(x+0.06, c(sm_m.15.cw, sm_m.16.cw, sm_m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
  lines(x-0.12, c(sm_m.15.fn, sm_m.16.fn, sm_m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
  lines(x-0.06, c(sm_m.15.fw, sm_m.16.fw, sm_m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")

  points(x,      c(sm_m.15.rf, sm_m.16.rf, sm_m.17.rf), cex = 1.8, lwd = 1, pch = 10)
  points(x+0.12, c(sm_m.15.cn, sm_m.16.cn, sm_m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg="white")
  points(x+0.06, c(sm_m.15.cw, sm_m.16.cw, sm_m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
  points(x-0.12, c(sm_m.15.fn, sm_m.16.fn, sm_m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg="white")
  points(x-0.06, c(sm_m.15.fw, sm_m.16.fw, sm_m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")
  
  ## large seedling graph
  plot(x1, c(-1000, -1000, -1000, -1000), type = "p", ylab = "", xlab = " ", cex = 1.5, 
       ylim = c(0, 100), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  #Total Seedling Cover
  mtext("c)", side = 3,line=1.5, cex=1, font=1, adj = 0)
  axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
  mtext("Year", side = 1, line = 3, cex = 1, font = 1)
  axis(2, pos = 1.2, seq(0,100,by=20), las=1)
  par(las = 0)
  mtext(expression("Large Seedlings 100 m "^-2), side = 2, line = 1.5, cex = 1, font = 2)
  
  x <- c(1.5, 2.5, 3.5)
  
  plot.errbars <- plotsegraph(x, c(lg_m.15.rf, lg_m.16.rf, lg_m.17.rf), 
                              c(lg_se.15.rf, lg_se.16.rf, lg_se.17.rf), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.12, c(lg_m.15.cn, lg_m.16.cn, lg_m.17.cn), 
                              c(lg_se.15.cn, lg_se.16.cn, lg_se.17.cn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x+0.06, c(lg_m.15.cw, lg_m.16.cw, lg_m.17.cw), 
                              c(lg_se.15.cw, lg_se.16.cw, lg_se.17.cw), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.12, c(lg_m.15.fn, lg_m.16.fn, lg_m.17.fn), 
                              c(lg_se.15.fn, lg_se.16.fn, lg_se.17.fn), 0.07, color = "black")  #0.07 = wiskwidth
  plot.errbars <- plotsegraph(x-0.06, c(lg_m.15.fw, lg_m.16.fw, lg_m.17.fw), 
                              c(lg_se.15.fw, lg_se.16.fw, lg_se.17.fw), 0.07, color = "black")  #0.07 = wiskwidth
 
  lines(x,      c(lg_m.15.rf, lg_m.16.rf, lg_m.17.rf), lwd = 1, type = "c", lty=1,col=colors()[c(320)])
  lines(x+0.12, c(lg_m.15.cn, lg_m.16.cn, lg_m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
  lines(x+0.06, c(lg_m.15.cw, lg_m.16.cw, lg_m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
  lines(x-0.12, c(lg_m.15.fn, lg_m.16.fn, lg_m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
  lines(x-0.06, c(lg_m.15.fw, lg_m.16.fw, lg_m.17.fw), lwd = 1, type = "c",lty=1, col = "darkorange")
  
  points(x,      c(lg_m.15.rf, lg_m.16.rf, lg_m.17.rf), cex = 1.8, lwd = 1, pch = 10)
  points(x+0.12, c(lg_m.15.cn, lg_m.16.cn, lg_m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg="white")
  points(x+0.06, c(lg_m.15.cw, lg_m.16.cw, lg_m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
  points(x-0.12, c(lg_m.15.fn, lg_m.16.fn, lg_m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg="white")
  points(x-0.06, c(lg_m.15.fw, lg_m.16.fw, lg_m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")
  
  par(mar=c(0,2,2,1)+0.1)
  plot(1,type="n",axes = F,xlab="",ylab="")
  LEGEND("topleft",pch=c(24,17,23,18,10), lty=c(1,2,2,1,1), col=c("royalblue3","royalblue3","darkorange","darkorange",colors()[(320)]),pt.bg="white",pt.col=c("royalblue3","royalblue3","darkorange","darkorange","black"),pt.cex=1.8,lwd=1,seg.len=4,bty = "n", cex=1.3, ncol=1,
         pt.lwd=1,y.intersp=1.3,x.intersp=1,legend = c("Cut-stump w/out mulch","Cut-stump w/ mulch","MH w/out mulch","MH w/ mulch", "Reference"))
  dev.off()
  
  