# Soil Temperature from iButtons buried 2 cm below soil surface #

library(lme4)
library(lmerTest)
library(multcomp)
library(psych)

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")

ibutton<-read.table("Soil Temperature_iButton 2cm Spring 2017.csv", sep=",", header=T)
  head(ibutton)
trt.assign<-read.table("Treatment Assignments.csv", sep=",", header=T)
    
iButton.matrix<-merge.data.frame(ibutton,trt.assign, by="Plot")

iButton.matrix$Mulch<-factor(iButton.matrix$Mulch, levels(iButton.matrix$Mulch)[c(2,1,3)])
  levels(iButton.matrix$Mulch) #ref should be first
iButton.matrix$Treatment<-factor(iButton.matrix$Treatment, levels(iButton.matrix$Treatment)[c(5,1,2,3,4)])
  levels(iButton.matrix$Treatment) #ref should be first
iButton.matrix$Removal<-factor(iButton.matrix$Removal, levels(iButton.matrix$Removal)[c(3,1,2)])
  levels(iButton.matrix$Removal) #ref should be first

attach(iButton.matrix)


contrast.matrix<-rbind("Ref. vs Unmulched" = c(0,0.5,0,0.5,0),
                       "Ref. vs Mulched" = c(0,0,0.5,0,0.5),
                       "Cut- vs. Fecon+" = c(0,-1,0,0,1),
                       "Cut vs. Fecon" = c(0,-0.5,-0.5,0.5,0.5),
                       "Unmulched vs Mulched" = c(0,-0.5,0.5,-0.5,0.5))  

lm.mean<-lmer(DailyMean~Treatment+(Day|Site:Plot)+(1|Day)+(1|Site))
  plot(lm.mean)
  hist(residuals(lm.mean))
  summary(lm.mean)
  anova(lm.mean)
  
  summary(glht(lm.mean, contrast.matrix)) #all treatments differ from ref, but no mulch effect on mean temperature
                                          # removal methods no different from one another

lm.min<-lmer(DailyMin~Treatment+(Day|Site:Plot)+(1|Day)+(1|Site)) 
  plot(lm.min) #super low values at PWA the first night of recording, drop day 1 values out of  set
  
iButton_noDay1<-subset(iButton.matrix, iButton.matrix$Day>1)
  detach(iButton.matrix)
  attach(iButton_noDay1)
# first redo mean model

lm.mean2<-lmer(DailyMean~Treatment+(Day|Site:Plot)+(1|Day)+(1|Site)) 
  plot(lm.mean2)
  hist(residuals(lm.mean2))
    summary(lm.mean2)
    anova(lm.mean2)

  summary(glht(lm.mean2, contrast.matrix))  #all treatments differ from ref, but no mulch effect on mean temperature
  # removal methods no different from one another


lm.min2<-lmer(DailyMin~Treatment+(Day|Site:Plot)+(1|Day)+(1|Site))
  plot(lm.min2)
  hist(residuals(lm.min2))
    anova(lm.min2)
    summary(glht(lm.min2, contrast.matrix)) #only mulched comparisons differed from Ref; significant mulch effect
                                              #ref vs unmulched est = 0.198 +- 0.106 p = 0.20
                                              #No removal method difference, just a mulch effect
    
lm.max2<-lmer(DailyMax~Treatment+(Day|Site:Plot)+(1|Day)+(1|Site))
  plot(lm.max2)
  hist(residuals(lm.max2))
    anova(lm.max2)
    summary(glht(lm.max2, contrast.matrix)) #max temps are lower in mulched  plots, but still > than in reference areas
  

iButton_noDay1$DailyRange<-iButton_noDay1$DailyMax-iButton_noDay1$DailyMin
  lm.range<-lmer(sqrt(iButton_noDay1$DailyRange+0.5)~Treatment+(Day|Site:Plot)+(1|Day)+(1|Site))
    plot(lm.range)
    hist(residuals(lm.range),breaks = 25)
    
    summary(glht(lm.range,contrast.matrix))
    

      